/********************************************************************************
** Form generated from reading UI file 'formMainWindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORMMAINWINDOW_H
#define UI_FORMMAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_formMainWindow
{
public:
    QWidget *centralWidget;
    QHBoxLayout *horizontalLayout_49;
    QWidget *widgetSidbar;
    QVBoxLayout *verticalLayout_32;
    QToolButton *toolButtonScreencast;
    QToolButton *toolButtonCamera;
    QToolButton *toolButtonShowclick;
    QToolButton *toolButtonSnapshot;
    QToolButton *toolButtonShortcut;
    QToolButton *toolButtonPlayer;
    QToolButton *toolButtonLog;
    QSpacerItem *verticalSpacer_16;
    QTabWidget *tabWidgetSideBar;
    QWidget *tabSidebarScreencast;
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidgetScreencast;
    QWidget *tabScreen;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_7;
    QGridLayout *gridLayout_3;
    QLabel *label_translate;
    QToolButton *toolButtonScreencastAreaReset;
    QToolButton *help_screencast_window;
    QRadioButton *radioButtonScreencastFullscreen;
    QToolButton *help_screencast_fullscreen;
    QComboBox *comboBoxScreencastScreen;
    QComboBox *comboBoxScreencastScreenArea;
    QRadioButton *radioButtonScreencastWindow;
    QRadioButton *radioButtonScreencastArea;
    QToolButton *toolButton_screen_name;
    QToolButton *help_screencast_area;
    QFrame *line_7;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_34;
    QScrollArea *scrollAreaAudioDevice;
    QWidget *scrollAreaWidgetContentsAudioDevices;
    QVBoxLayout *verticalLayoutAudioDevices;
    QVBoxLayout *verticalLayout_15;
    QToolButton *help_screencast_audio;
    QSpacerItem *verticalSpacer_28;
    QHBoxLayout *horizontalLayout_37;
    QLabel *labelAudioCodec;
    QComboBox *comboBoxAudioCodec;
    QSpacerItem *horizontalSpacer_14;
    QToolButton *help_screencast_audiocodec;
    QFrame *line_10;
    QFrame *line_9;
    QGridLayout *gridLayout_13;
    QToolButton *toolButton_magnifier_rectangle;
    QCheckBox *checkBoxMagnifier;
    QToolButton *help_screencast_magnifier;
    QLabel *label_magnifier_on_screen;
    QHBoxLayout *horizontalLayout_60;
    QLabel *labelScreencastCountdownText;
    QToolButton *toolButton_magnifier_elipse;
    QFrame *line_11;
    QToolButton *help_screencast_countdown;
    QHBoxLayout *horizontalLayout_rectangle;
    QToolButton *toolButton_magnifier_circle;
    QHBoxLayout *horizontalLayout_elipse;
    QHBoxLayout *horizontalLayout_circle;
    QFrame *line_5;
    QGridLayout *gridLayout_6;
    QGridLayout *gridLayout_5;
    QLabel *label_25;
    QLabel *labelInfoVideocodec;
    QLabel *labelInfoFormat;
    QLabel *label_14;
    QSpacerItem *verticalSpacer_4;
    QLabel *labelInfoAudiocodec;
    QLabel *label_16;
    QFrame *line_3;
    QLabel *label_15;
    QLabel *label_12;
    QLabel *label_23;
    QLabel *labelInfoRecordTime;
    QLabel *label_24;
    QLabel *labelFreeSize;
    QLabel *label_29;
    QLabel *labelVideoSize;
    QLabel *label_13;
    QLabel *labelInfoFrames;
    QSpacerItem *verticalSpacer_21;
    QLabel *label_Upate_tab_1;
    QLabel *label_17;
    QWidget *tabVideo;
    QWidget *widget;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayoutFormatCodecs;
    QFrame *frameVideoCodecQuality;
    QVBoxLayout *verticalLayout_9;
    QFrame *frameVideoCodecx264;
    QHBoxLayout *horizontalLayout_x264;
    QVBoxLayout *verticalLayout_19;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *comboBoxx264Preset;
    QComboBox *comboBoxx264Profile;
    QHBoxLayout *horizontalLayout_26;
    QLabel *label_21;
    QToolButton *toolButtonx264Reset;
    QFrame *frameVideoCodecOpenh264;
    QHBoxLayout *horizontalLayout_64;
    QVBoxLayout *verticalLayout_40;
    QHBoxLayout *horizontalLayout_67;
    QLabel *label_61;
    QComboBox *comboBox_openh264_profile;
    QHBoxLayout *horizontalLayout_openh264;
    QLabel *label_19;
    QToolButton *toolButtonOpenh264Reset;
    QFrame *frameVideoCodecGIF;
    QHBoxLayout *horizontalLayout_62;
    QCheckBox *checkBoxGifLoop;
    QComboBox *comboBoxFormat;
    QLabel *labelFormat;
    QComboBox *comboBoxVideoCodec;
    QFrame *frameFrames;
    QHBoxLayout *horizontalLayout_33;
    QToolButton *toolButtonFramesReset;
    QToolButton *help_screencast_frames;
    QSpacerItem *horizontalSpacer_42;
    QHBoxLayout *horizontalLayout_22;
    QCheckBox *checkBoxMouseCursorOnOff;
    QVBoxLayout *verticalLayout_22;
    QLabel *labelVideoCodec;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *help_screencast_nomousecursor;
    QLabel *labelFrames;
    QToolButton *help_screencast_videocodec;
    QToolButton *help_screencast_format;
    QWidget *tabMisc;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_8;
    QSpacerItem *verticalSpacer_23;
    QSpacerItem *verticalSpacer_14;
    QToolButton *help_screencast_limitoffreediskspace;
    QToolButton *help_screencast_SecondWaitBeforeRecording;
    QHBoxLayout *horizontalLayout_25;
    QFrame *frameVideoPath;
    QHBoxLayout *horizontalLayout_20;
    QLabel *LabelVideoPath;
    QLineEdit *lineEditVideoPath;
    QToolButton *toolButtonVideoPath;
    QGridLayout *gridLayout_14;
    QSpacerItem *horizontalSpacer_52;
    QLabel *label_20;
    QComboBox *comboBoxLanguage;
    QSpacerItem *horizontalSpacer_29;
    QComboBox *comboBoxOnlineHelp;
    QLabel *label_66;
    QToolButton *help_screencast_startsminimized;
    QHBoxLayout *horizontalLayout_21;
    QFrame *frameShowInSystray;
    QHBoxLayout *horizontalLayout_30;
    QCheckBox *checkBoxShowInSystray;
    QSpacerItem *horizontalSpacer_8;
    QFrame *frameShowInSystrayAlternative;
    QHBoxLayout *horizontalLayout_18;
    QCheckBox *checkBoxShowInSystrayAlternative;
    QToolButton *help_screencast_deleteallsettings;
    QHBoxLayout *horizontalLayout_31;
    QCheckBox *checkBoxStartsMinimized;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_28;
    QFrame *frameLimitOfFreeDiskSpace;
    QHBoxLayout *horizontalLayout_27;
    QLabel *label_10;
    QLabel *label_11;
    QToolButton *help_screencast_lookforupdates;
    QHBoxLayout *horizontalLayout_23;
    QCheckBox *checkBoxMinimizedWhenRecordingStarts;
    QHBoxLayout *horizontalLayout_17;
    QCheckBox *checkBoxLookForUpdates;
    QLabel *label_Upate_tab_4;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_18;
    QSpacerItem *horizontalSpacer_44;
    QToolButton *help_screencast_showinsystray;
    QCheckBox *checkBoxResetAtNextStart;
    QHBoxLayout *horizontalLayout_darkMode;
    QLabel *label_65;
    QLabel *label_63;
    QSpacerItem *horizontalSpacer_12;
    QToolButton *help_screencast_videopath;
    QToolButton *toolButtonShowInSystrayAlternativeReset;
    QToolButton *help_screencast_minimizedwhenrecordingstarts;
    QHBoxLayout *horizontalLayout_36;
    QCheckBox *checkBoxGstreamerDebugLevel;
    QPushButton *pushButtonGstreamerDebugLevel;
    QSpacerItem *horizontalSpacer_46;
    QToolButton *help_screencast_gstreamerDebugLevel;
    QFrame *frameProfile;
    QHBoxLayout *horizontalLayout_13;
    QLabel *labelProfile;
    QComboBox *comboBoxProfile;
    QPushButton *pushButtonProfileSave;
    QPushButton *pushButtonProfileNew;
    QPushButton *pushButtonProfileDelete;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_5;
    QWidget *tabTimer;
    QVBoxLayout *verticalLayout_23;
    QHBoxLayout *horizontalLayout_29;
    QFrame *frameStartTime;
    QHBoxLayout *horizontalLayout_24;
    QVBoxLayout *verticalLayout_18;
    QLabel *labelHour;
    QLabel *labelMinute;
    QVBoxLayout *verticalLayout_14;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayout_46;
    QCheckBox *checkBoxStartTime;
    QSpacerItem *horizontalSpacer_17;
    QToolButton *help_screencast_starttimer;
    QFrame *line;
    QHBoxLayout *horizontalLayout_19;
    QCheckBox *checkBoxStopRecordingAfter;
    QFrame *frameStopRecordingAfter;
    QHBoxLayout *horizontalLayout_16;
    QVBoxLayout *verticalLayout_30;
    QLabel *label_7;
    QLabel *label_8;
    QLabel *label_9;
    QVBoxLayout *verticalLayout_29;
    QToolButton *help_screencast_stoptimer;
    QSpacerItem *verticalSpacer_8;
    QWidget *tabAvailable;
    QHBoxLayout *horizontalLayout_11;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QLabel *label_2;
    QLabel *label;
    QScrollArea *scrollAreaAvailable;
    QWidget *scrollAreaWidgetContentsAvailable;
    QGridLayout *gridLayoutAvailable;
    QVBoxLayout *verticalLayout_12;
    QVBoxLayout *verticalLayout_8;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_6;
    QLabel *labelAvalible;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_9;
    QLabel *labelNotAvailable;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer_23;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_10;
    QToolButton *help_screencast_avalaible;
    QSpacerItem *verticalSpacer_6;
    QWidget *tabAbout;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer_3;
    QGridLayout *gridLayout_7;
    QLabel *labelAutorPicture;
    QVBoxLayout *verticalLayout_27;
    QLabel *labelSourcecodeUrl;
    QLabel *labelWebSiteUrl;
    QVBoxLayout *verticalLayout_31;
    QLabel *labelLanguageUrl;
    QLabel *labelDonateUrl;
    QSpacerItem *verticalSpacer_11;
    QFrame *line_13;
    QSpacerItem *verticalSpacer_12;
    QHBoxLayout *horizontalLayout_10;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *pushButtonLicense;
    QSpacerItem *horizontalSpacer_10;
    QSpacerItem *verticalSpacer_25;
    QHBoxLayout *horizontalLayout_58;
    QSpacerItem *horizontalSpacer_51;
    QPushButton *pushButtonImages;
    QSpacerItem *horizontalSpacer_28;
    QLabel *label_save_image_path;
    QFrame *line_cisco;
    QFrame *frame_cisco;
    QVBoxLayout *verticalLayout_13;
    QGridLayout *gridLayout_2;
    QFrame *frame;
    QVBoxLayout *verticalLayout_20;
    QLabel *label_cisco_hint;
    QPushButton *pushButtonCiscoLicense;
    QLabel *label_openh264_homepage;
    QHBoxLayout *horizontalLayout_35;
    QSpacerItem *horizontalSpacer_21;
    QRadioButton *radioButton_cisco_on;
    QRadioButton *radioButton_cisco_off;
    QSpacerItem *horizontalSpacer_20;
    QHBoxLayout *horizontalLayout;
    QPushButton *pushButtonStart;
    QPushButton *pushButtonStop;
    QPushButton *pushButtonPause;
    QPushButton *pushButtonContinue;
    QPushButton *pushButtonPlay;
    QPushButton *pushButtonScreencastOpenfolder;
    QPushButton *pushButtonScreencastSnapshot;
    QToolButton *help_screencast_execute;
    QWidget *tabSidebarCamera;
    QVBoxLayout *verticalLayout_17;
    QTabWidget *tabWidgetCamera;
    QWidget *tabCamera;
    QVBoxLayout *verticalLayout_16;
    QGridLayout *gridLayout_4;
    QToolButton *help_camera_camera;
    QLabel *label_camera_window_zoom;
    QHBoxLayout *horizontalLayout_14;
    QCheckBox *checkBoxCameraInvert;
    QSpacerItem *horizontalSpacer_39;
    QCheckBox *checkBoxCameraGray;
    QSpacerItem *horizontalSpacer_40;
    QCheckBox *checkBoxCameraMono;
    QSpacerItem *horizontalSpacer_33;
    QHBoxLayout *horizontalLayout_zoom;
    QHBoxLayout *horizontalLayout_63;
    QCheckBox *checkBoxCameraOnOff;
    QComboBox *comboBoxCamera;
    QComboBox *comboBoxCameraResolution;
    QHBoxLayout *horizontalLayout_66;
    QHBoxLayout *horizontalLayout_45;
    QLabel *labelCameraWindowSize;
    QLabel *label_camera_window_resize;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *checkBoxCameraMirrorVertical;
    QSpacerItem *horizontalSpacer_38;
    QCheckBox *checkBoxCameraMirrorHorizontal;
    QSpacerItem *horizontalSpacer_7;
    QHBoxLayout *horizontalLayout_65;
    QSpacerItem *horizontalSpacer_41;
    QToolButton *toolButton_camera_view_rectangle;
    QSpacerItem *horizontalSpacer_35;
    QToolButton *toolButton_camera_view_ellipse;
    QSpacerItem *horizontalSpacer_36;
    QToolButton *toolButton_camera_view_circle;
    QSpacerItem *horizontalSpacer_37;
    QHBoxLayout *horizontalLayout_42;
    QCheckBox *checkBoxCameraWindowFrame;
    QSpacerItem *verticalSpacer_26;
    QWidget *tabSidebarShowClick;
    QHBoxLayout *horizontalLayout_40;
    QTabWidget *tabWidgetShowClick;
    QWidget *tab;
    QVBoxLayout *verticalLayout_35;
    QGridLayout *gridLayoutShowClick;
    QFrame *line_4;
    QHBoxLayout *horizontalLayout_41;
    QLabel *label_30;
    QHBoxLayout *horizontalLayoutDiameter;
    QToolButton *toolButtonHaloOpacityDefault;
    QToolButton *toolButtonHaloDiameterDefault;
    QGridLayout *gridLayout_showclick_color_pushButton;
    QHBoxLayout *horizontalLayout_showclick_darkRed;
    QHBoxLayout *horizontalLayout_showclick_darkGreen;
    QHBoxLayout *horizontalLayout_showclick_white;
    QHBoxLayout *horizontalLayout_showclick_green;
    QToolButton *toolButtonShowclickColorDefault;
    QHBoxLayout *horizontalLayout_showclick_red;
    QHBoxLayout *horizontalLayout_showclick_yellow;
    QHBoxLayout *horizontalLayout_showclick_darkYellow;
    QHBoxLayout *horizontalLayout_showclick_darkMagenta;
    QHBoxLayout *horizontalLayout_showclick_blue;
    QHBoxLayout *horizontalLayout_showclick_magenta;
    QHBoxLayout *horizontalLayout_showclick_gray;
    QHBoxLayout *horizontalLayout_showclick_cyan;
    QHBoxLayout *horizontalLayout_showclick_darkBlue;
    QHBoxLayout *horizontalLayout_showclick_darkGray;
    QHBoxLayout *horizontalLayout_showclick_black;
    QHBoxLayout *horizontalLayout_showclick_darkCyan;
    QHBoxLayout *horizontalLayout_43;
    QLabel *label_31;
    QHBoxLayout *horizontalLayoutHaloOpacity;
    QHBoxLayout *horizontalLayout_32;
    QLabel *label_27;
    QHBoxLayout *horizontalLayoutOpacity;
    QToolButton *toolButtonShowclickDiameterDefault;
    QFrame *frame_3;
    QHBoxLayout *horizontalLayout_38;
    QToolButton *toolButtonShowclickOpacityDefault;
    QGridLayout *gridLayout_halo_color_pushButton;
    QHBoxLayout *horizontalLayout_halo_darkGray;
    QHBoxLayout *horizontalLayout_halo_green;
    QHBoxLayout *horizontalLayout_halo_red;
    QHBoxLayout *horizontalLayout_halo_cyan;
    QHBoxLayout *horizontalLayout_halo_white;
    QHBoxLayout *horizontalLayout_halo_magenta;
    QHBoxLayout *horizontalLayout_halo_darkMagenta;
    QHBoxLayout *horizontalLayout_halo_darkGreen;
    QHBoxLayout *horizontalLayout_halo_black;
    QHBoxLayout *horizontalLayout_halo_darkCyan;
    QHBoxLayout *horizontalLayout_halo_darkYellow;
    QHBoxLayout *horizontalLayout_halo_blue;
    QHBoxLayout *horizontalLayout_halo_darkBlue;
    QHBoxLayout *horizontalLayout_halo_gray;
    QHBoxLayout *horizontalLayout_halo_darkRed;
    QHBoxLayout *horizontalLayout_halo_yellow;
    QToolButton *toolButtonHaloColorDefault;
    QHBoxLayout *horizontalLayout_15;
    QSpacerItem *horizontalSpacer_11;
    QSpacerItem *horizontalSpacer_5;
    QToolButton *toolButtonHaloHoleDefault;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_26;
    QHBoxLayout *horizontalLayoutShowtime;
    QHBoxLayout *horizontalLayout_47;
    QLabel *label_32;
    QHBoxLayout *horizontalLayoutHaloHole;
    QHBoxLayout *horizontalLayout_48;
    QSpacerItem *horizontalSpacer_15;
    QSpacerItem *horizontalSpacer_13;
    QLabel *label_33;
    QLabel *label_34;
    QSpacerItem *verticalSpacer_27;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout_61;
    QHBoxLayout *horizontalLayout_39;
    QLabel *label_28;
    QHBoxLayout *horizontalLayoutCircle;
    QToolButton *toolButtonShowclickTimeDefault;
    QFrame *line_8;
    QFrame *line_6;
    QWidget *tabSidebarSnapShot;
    QVBoxLayout *verticalLayout_36;
    QVBoxLayout *verticalLayout_38;
    QTabWidget *tabWidgetSnapshot;
    QWidget *tabSnapshot;
    QVBoxLayout *verticalLayout_37;
    QGridLayout *gridLayout_10;
    QLabel *label_57;
    QToolButton *toolButtonSnapshotImagePath;
    QLabel *label_60;
    QLineEdit *lineEditSnapshotImagePath;
    QHBoxLayout *horizontalLayout_44;
    QComboBox *comboBoxSnapshotImageFormats;
    QSpacerItem *horizontalSpacer_24;
    QCheckBox *checkBoxSnapshotShowBallonInSystray;
    QLabel *label_56;
    QFrame *line_2;
    QCheckBox *checkBoxSnapshotHideBeforeRecording;
    QHBoxLayout *horizontalLayout_59;
    QLabel *label_59;
    QSpacerItem *verticalSpacer_10;
    QGridLayout *gridLayout_12;
    QPushButton *pushButtonSnapshotSnapshot;
    QSpacerItem *horizontalSpacer_31;
    QPushButton *pushButtonSnapshotOpenfolder;
    QWidget *tabSidebarShortcut;
    QVBoxLayout *verticalLayout_33;
    QTabWidget *tabWidgetShortcut;
    QWidget *tabShortcut;
    QVBoxLayout *verticalLayout_34;
    QFrame *frame_screencast_shortcut;
    QVBoxLayout *verticalLayout_24;
    QHBoxLayout *horizontalLayout_51;
    QSpacerItem *horizontalSpacer_22;
    QLabel *label_45;
    QSpacerItem *horizontalSpacer_19;
    QHBoxLayout *horizontalLayout_52;
    QSpacerItem *horizontalSpacer_25;
    QGridLayout *gridLayout_11;
    QSpacerItem *horizontalSpacer_26;
    QCheckBox *checkBox_shortcut_start_strg;
    QCheckBox *checkBox_shortcut_magnification_alt;
    QHBoxLayout *horizontalLayout_55;
    QLabel *label_47;
    QSpacerItem *horizontalSpacer_34;
    QHBoxLayout *horizontalLayout_53;
    QLabel *label_40;
    QLabel *label_46;
    QLabel *label_41;
    QSpacerItem *horizontalSpacer_30;
    QLabel *label_shortcut_picture_magnification;
    QCheckBox *checkBox_shortcut_start_meta;
    QCheckBox *checkBox_shortcut_pause_meta;
    QCheckBox *checkBox_shortcut_start_shift;
    QCheckBox *checkBox_shortcut_camera_meta;
    QLabel *label_shortcut_picture_camera;
    QLabel *label_37;
    QToolButton *toolButton_shortcut_reset_pause;
    QCheckBox *checkBox_shortcut_camera_alt;
    QCheckBox *checkBox_shortcut_pause_alt;
    QComboBox *comboBox_shortcut_camera;
    QCheckBox *checkBox_shortcut_halo_meta;
    QCheckBox *checkBox_shortcut_showclick_shift;
    QLabel *label_shortcut_picture_halo;
    QCheckBox *checkBox_shortcut_magnification_shift;
    QLabel *label_36;
    QCheckBox *checkBox_shortcut_camera_shift;
    QToolButton *toolButton_shortcut_reset_showclick;
    QComboBox *comboBox_shortcut_halo;
    QCheckBox *checkBox_shortcut_magnification_strg;
    QCheckBox *checkBox_shortcut_showclick_strg;
    QLabel *label_shortcut_picture_showclick;
    QCheckBox *checkBox_shortcut_camera_strg;
    QCheckBox *checkBox_shortcut_start_alt;
    QToolButton *toolButton_shortcut_reset_halo;
    QComboBox *comboBox_shortcut_magnification;
    QCheckBox *checkBox_shortcut_pause_shift;
    QLabel *label_shortcut_picture_pause;
    QCheckBox *checkBox_shortcut_halo_strg;
    QLabel *label_49;
    QToolButton *toolButton_shortcut_reset_camera;
    QCheckBox *checkBox_shortcut_showclick_meta;
    QLabel *label_51;
    QToolButton *toolButton_shortcut_reset_start;
    QLabel *label_35;
    QHBoxLayout *horizontalLayout_50;
    QLabel *label_43;
    QLabel *label_48;
    QLabel *label_44;
    QSpacerItem *horizontalSpacer_27;
    QCheckBox *checkBox_shortcut_showclick_alt;
    QComboBox *comboBox_shortcut_pause;
    QHBoxLayout *horizontalLayout_54;
    QLabel *label_42;
    QSpacerItem *horizontalSpacer_32;
    QCheckBox *checkBox_shortcut_pause_strg;
    QToolButton *toolButton_shortcut_reset_magnification;
    QLabel *label_38;
    QComboBox *comboBox_shortcut_start;
    QComboBox *comboBox_shortcut_showclick;
    QCheckBox *checkBox_shortcut_halo_shift;
    QCheckBox *checkBox_shortcut_halo_alt;
    QCheckBox *checkBox_shortcut_magnification_meta;
    QLabel *label_shortcut_picture_start;
    QLabel *label_58;
    QLabel *label_shortcut_picture_snapshot;
    QCheckBox *checkBox_shortcut_snapshot_strg;
    QCheckBox *checkBox_shortcut_snapshot_shift;
    QCheckBox *checkBox_shortcut_snapshot_alt;
    QCheckBox *checkBox_shortcut_snapshot_meta;
    QComboBox *comboBox_shortcut_snapshot;
    QToolButton *toolButton_shortcut_reset_snapshot;
    QSpacerItem *verticalSpacer_24;
    QHBoxLayout *horizontalLayout_56;
    QLabel *label_39;
    QLabel *label_50;
    QHBoxLayout *horizontalLayout_57;
    QLabel *label_52;
    QLabel *label_53;
    QSpacerItem *verticalSpacer_15;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_54;
    QSpacerItem *verticalSpacer_22;
    QWidget *tabSidebarPlayer;
    QVBoxLayout *verticalLayoutTabSidebarPlayer;
    QTabWidget *tabWidgetPlayer;
    QWidget *tab_2;
    QHBoxLayout *horizontalLayout_68;
    QSpacerItem *horizontalSpacer_50;
    QPushButton *pushButtonPlayer;
    QSpacerItem *horizontalSpacer_54;
    QWidget *tabSidebarLog;
    QVBoxLayout *verticalLayout_25;
    QTabWidget *tabWidgetLog;
    QWidget *tabLog;
    QVBoxLayout *verticalLayout_26;
    QTextBrowser *textBrowser;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_16;
    QPushButton *pushButton_log_openfolder;
    QPushButton *pushButton_log_refresh;
    QButtonGroup *buttonGroup;
    QButtonGroup *buttonGroup_2;

    void setupUi(QMainWindow *formMainWindow)
    {
        if (formMainWindow->objectName().isEmpty())
            formMainWindow->setObjectName("formMainWindow");
        formMainWindow->resize(897, 560);
        formMainWindow->setWindowTitle(QString::fromUtf8(""));
        centralWidget = new QWidget(formMainWindow);
        centralWidget->setObjectName("centralWidget");
        horizontalLayout_49 = new QHBoxLayout(centralWidget);
        horizontalLayout_49->setSpacing(0);
        horizontalLayout_49->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_49->setObjectName("horizontalLayout_49");
        horizontalLayout_49->setContentsMargins(0, 0, 0, 0);
        widgetSidbar = new QWidget(centralWidget);
        widgetSidbar->setObjectName("widgetSidbar");
        verticalLayout_32 = new QVBoxLayout(widgetSidbar);
        verticalLayout_32->setSpacing(0);
        verticalLayout_32->setContentsMargins(11, 11, 11, 11);
        verticalLayout_32->setObjectName("verticalLayout_32");
        verticalLayout_32->setContentsMargins(0, 0, 0, 0);
        toolButtonScreencast = new QToolButton(widgetSidbar);
        toolButtonScreencast->setObjectName("toolButtonScreencast");
        toolButtonScreencast->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonScreencast->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonScreencast->setText(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/pictures/screencast/monitor.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonScreencast->setIcon(icon);
        toolButtonScreencast->setIconSize(QSize(48, 48));
        toolButtonScreencast->setCheckable(true);
        toolButtonScreencast->setAutoExclusive(true);
        toolButtonScreencast->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonScreencast);

        toolButtonCamera = new QToolButton(widgetSidbar);
        toolButtonCamera->setObjectName("toolButtonCamera");
        toolButtonCamera->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonCamera->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonCamera->setText(QString::fromUtf8(""));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/pictures/camera/camera.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonCamera->setIcon(icon1);
        toolButtonCamera->setIconSize(QSize(48, 48));
        toolButtonCamera->setCheckable(true);
        toolButtonCamera->setAutoExclusive(true);
        toolButtonCamera->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonCamera);

        toolButtonShowclick = new QToolButton(widgetSidbar);
        toolButtonShowclick->setObjectName("toolButtonShowclick");
        toolButtonShowclick->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonShowclick->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonShowclick->setText(QString::fromUtf8(""));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/pictures/showClick/vokoShowClick-sidebar.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonShowclick->setIcon(icon2);
        toolButtonShowclick->setIconSize(QSize(48, 48));
        toolButtonShowclick->setCheckable(true);
        toolButtonShowclick->setAutoExclusive(true);
        toolButtonShowclick->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonShowclick);

        toolButtonSnapshot = new QToolButton(widgetSidbar);
        toolButtonSnapshot->setObjectName("toolButtonSnapshot");
        toolButtonSnapshot->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonSnapshot->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonSnapshot->setText(QString::fromUtf8(""));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/pictures/snapshot/snapshot.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonSnapshot->setIcon(icon3);
        toolButtonSnapshot->setIconSize(QSize(48, 48));
        toolButtonSnapshot->setCheckable(true);
        toolButtonSnapshot->setAutoExclusive(true);
        toolButtonSnapshot->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonSnapshot);

        toolButtonShortcut = new QToolButton(widgetSidbar);
        toolButtonShortcut->setObjectName("toolButtonShortcut");
        toolButtonShortcut->setMinimumSize(QSize(110, 56));
        toolButtonShortcut->setText(QString::fromUtf8(""));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/pictures/screencast/shortcut.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonShortcut->setIcon(icon4);
        toolButtonShortcut->setIconSize(QSize(48, 48));
        toolButtonShortcut->setCheckable(true);
        toolButtonShortcut->setAutoExclusive(true);
        toolButtonShortcut->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonShortcut);

        toolButtonPlayer = new QToolButton(widgetSidbar);
        toolButtonPlayer->setObjectName("toolButtonPlayer");
        toolButtonPlayer->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonPlayer->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonPlayer->setText(QString::fromUtf8(""));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/pictures/player/player.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonPlayer->setIcon(icon5);
        toolButtonPlayer->setIconSize(QSize(48, 48));
        toolButtonPlayer->setCheckable(true);
        toolButtonPlayer->setAutoExclusive(true);
        toolButtonPlayer->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonPlayer);

        toolButtonLog = new QToolButton(widgetSidbar);
        toolButtonLog->setObjectName("toolButtonLog");
        toolButtonLog->setMinimumSize(QSize(110, 56));
#if QT_CONFIG(tooltip)
        toolButtonLog->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        toolButtonLog->setText(QString::fromUtf8(""));
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/pictures/log/log.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonLog->setIcon(icon6);
        toolButtonLog->setIconSize(QSize(48, 48));
        toolButtonLog->setCheckable(true);
        toolButtonLog->setAutoExclusive(true);
        toolButtonLog->setAutoRaise(true);

        verticalLayout_32->addWidget(toolButtonLog);

        verticalSpacer_16 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_32->addItem(verticalSpacer_16);


        horizontalLayout_49->addWidget(widgetSidbar);

        tabWidgetSideBar = new QTabWidget(centralWidget);
        tabWidgetSideBar->setObjectName("tabWidgetSideBar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidgetSideBar->sizePolicy().hasHeightForWidth());
        tabWidgetSideBar->setSizePolicy(sizePolicy);
        tabWidgetSideBar->setAcceptDrops(false);
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabPosition(QTabWidget::West);
        tabWidgetSideBar->setIconSize(QSize(0, 0));
        tabSidebarScreencast = new QWidget();
        tabSidebarScreencast->setObjectName("tabSidebarScreencast");
        verticalLayout = new QVBoxLayout(tabSidebarScreencast);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidgetScreencast = new QTabWidget(tabSidebarScreencast);
        tabWidgetScreencast->setObjectName("tabWidgetScreencast");
        sizePolicy.setHeightForWidth(tabWidgetScreencast->sizePolicy().hasHeightForWidth());
        tabWidgetScreencast->setSizePolicy(sizePolicy);
#if QT_CONFIG(tooltip)
        tabWidgetScreencast->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        tabWidgetScreencast->setIconSize(QSize(48, 48));
        tabWidgetScreencast->setUsesScrollButtons(false);
        tabScreen = new QWidget();
        tabScreen->setObjectName("tabScreen");
        horizontalLayout_2 = new QHBoxLayout(tabScreen);
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout_7 = new QVBoxLayout();
        verticalLayout_7->setSpacing(6);
        verticalLayout_7->setObjectName("verticalLayout_7");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setSpacing(6);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setVerticalSpacing(3);
        gridLayout_3->setContentsMargins(-1, -1, -1, 0);
        label_translate = new QLabel(tabScreen);
        label_translate->setObjectName("label_translate");
        label_translate->setText(QString::fromUtf8("Translate"));
        label_translate->setWordWrap(true);
        label_translate->setOpenExternalLinks(true);

        gridLayout_3->addWidget(label_translate, 3, 0, 1, 4);

        toolButtonScreencastAreaReset = new QToolButton(tabScreen);
        toolButtonScreencastAreaReset->setObjectName("toolButtonScreencastAreaReset");
        toolButtonScreencastAreaReset->setText(QString::fromUtf8(""));
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/pictures/screencast/undo.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonScreencastAreaReset->setIcon(icon7);

        gridLayout_3->addWidget(toolButtonScreencastAreaReset, 2, 2, 1, 1);

        help_screencast_window = new QToolButton(tabScreen);
        help_screencast_window->setObjectName("help_screencast_window");
        help_screencast_window->setText(QString::fromUtf8("Help"));

        gridLayout_3->addWidget(help_screencast_window, 1, 3, 1, 1);

        radioButtonScreencastFullscreen = new QRadioButton(tabScreen);
        buttonGroup = new QButtonGroup(formMainWindow);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(radioButtonScreencastFullscreen);
        radioButtonScreencastFullscreen->setObjectName("radioButtonScreencastFullscreen");

        gridLayout_3->addWidget(radioButtonScreencastFullscreen, 0, 0, 1, 1);

        help_screencast_fullscreen = new QToolButton(tabScreen);
        help_screencast_fullscreen->setObjectName("help_screencast_fullscreen");
        help_screencast_fullscreen->setText(QString::fromUtf8("Help"));

        gridLayout_3->addWidget(help_screencast_fullscreen, 0, 3, 1, 1);

        comboBoxScreencastScreen = new QComboBox(tabScreen);
        comboBoxScreencastScreen->setObjectName("comboBoxScreencastScreen");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboBoxScreencastScreen->sizePolicy().hasHeightForWidth());
        comboBoxScreencastScreen->setSizePolicy(sizePolicy1);
        comboBoxScreencastScreen->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_3->addWidget(comboBoxScreencastScreen, 0, 1, 1, 1);

        comboBoxScreencastScreenArea = new QComboBox(tabScreen);
        comboBoxScreencastScreenArea->setObjectName("comboBoxScreencastScreenArea");
        comboBoxScreencastScreenArea->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_3->addWidget(comboBoxScreencastScreenArea, 2, 1, 1, 1);

        radioButtonScreencastWindow = new QRadioButton(tabScreen);
        buttonGroup->addButton(radioButtonScreencastWindow);
        radioButtonScreencastWindow->setObjectName("radioButtonScreencastWindow");

        gridLayout_3->addWidget(radioButtonScreencastWindow, 1, 0, 1, 1);

        radioButtonScreencastArea = new QRadioButton(tabScreen);
        buttonGroup->addButton(radioButtonScreencastArea);
        radioButtonScreencastArea->setObjectName("radioButtonScreencastArea");

        gridLayout_3->addWidget(radioButtonScreencastArea, 2, 0, 1, 1);

        toolButton_screen_name = new QToolButton(tabScreen);
        toolButton_screen_name->setObjectName("toolButton_screen_name");
        toolButton_screen_name->setText(QString::fromUtf8(""));
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/pictures/screencast/screen-name.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_screen_name->setIcon(icon8);
        toolButton_screen_name->setCheckable(true);

        gridLayout_3->addWidget(toolButton_screen_name, 0, 2, 1, 1);

        help_screencast_area = new QToolButton(tabScreen);
        help_screencast_area->setObjectName("help_screencast_area");
        help_screencast_area->setText(QString::fromUtf8("Help"));

        gridLayout_3->addWidget(help_screencast_area, 2, 3, 1, 1);


        verticalLayout_7->addLayout(gridLayout_3);

        line_7 = new QFrame(tabScreen);
        line_7->setObjectName("line_7");
        line_7->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_7->setFrameShadow(QFrame::Plain);
        line_7->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_7);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(6);
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_34 = new QHBoxLayout();
        horizontalLayout_34->setSpacing(6);
        horizontalLayout_34->setObjectName("horizontalLayout_34");
        scrollAreaAudioDevice = new QScrollArea(tabScreen);
        scrollAreaAudioDevice->setObjectName("scrollAreaAudioDevice");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(scrollAreaAudioDevice->sizePolicy().hasHeightForWidth());
        scrollAreaAudioDevice->setSizePolicy(sizePolicy2);
#if QT_CONFIG(accessibility)
        scrollAreaAudioDevice->setAccessibleName(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        scrollAreaAudioDevice->setFrameShape(QFrame::NoFrame);
        scrollAreaAudioDevice->setWidgetResizable(true);
        scrollAreaAudioDevice->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        scrollAreaWidgetContentsAudioDevices = new QWidget();
        scrollAreaWidgetContentsAudioDevices->setObjectName("scrollAreaWidgetContentsAudioDevices");
        scrollAreaWidgetContentsAudioDevices->setGeometry(QRect(0, 0, 489, 222));
#if QT_CONFIG(accessibility)
        scrollAreaWidgetContentsAudioDevices->setAccessibleName(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        verticalLayoutAudioDevices = new QVBoxLayout(scrollAreaWidgetContentsAudioDevices);
        verticalLayoutAudioDevices->setSpacing(3);
        verticalLayoutAudioDevices->setContentsMargins(11, 11, 11, 11);
        verticalLayoutAudioDevices->setObjectName("verticalLayoutAudioDevices");
        verticalLayoutAudioDevices->setContentsMargins(0, 6, 6, 0);
        scrollAreaAudioDevice->setWidget(scrollAreaWidgetContentsAudioDevices);

        horizontalLayout_34->addWidget(scrollAreaAudioDevice);

        verticalLayout_15 = new QVBoxLayout();
        verticalLayout_15->setSpacing(6);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalLayout_15->setContentsMargins(-1, 2, -1, -1);
        help_screencast_audio = new QToolButton(tabScreen);
        help_screencast_audio->setObjectName("help_screencast_audio");
        help_screencast_audio->setText(QString::fromUtf8("Help"));

        verticalLayout_15->addWidget(help_screencast_audio);

        verticalSpacer_28 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_15->addItem(verticalSpacer_28);


        horizontalLayout_34->addLayout(verticalLayout_15);


        verticalLayout_5->addLayout(horizontalLayout_34);

        horizontalLayout_37 = new QHBoxLayout();
        horizontalLayout_37->setSpacing(6);
        horizontalLayout_37->setObjectName("horizontalLayout_37");
        labelAudioCodec = new QLabel(tabScreen);
        labelAudioCodec->setObjectName("labelAudioCodec");

        horizontalLayout_37->addWidget(labelAudioCodec);

        comboBoxAudioCodec = new QComboBox(tabScreen);
        comboBoxAudioCodec->setObjectName("comboBoxAudioCodec");
        comboBoxAudioCodec->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_37->addWidget(comboBoxAudioCodec);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_37->addItem(horizontalSpacer_14);

        help_screencast_audiocodec = new QToolButton(tabScreen);
        help_screencast_audiocodec->setObjectName("help_screencast_audiocodec");
        help_screencast_audiocodec->setText(QString::fromUtf8("Help"));

        horizontalLayout_37->addWidget(help_screencast_audiocodec);


        verticalLayout_5->addLayout(horizontalLayout_37);


        verticalLayout_7->addLayout(verticalLayout_5);

        line_10 = new QFrame(tabScreen);
        line_10->setObjectName("line_10");
        line_10->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_10->setFrameShadow(QFrame::Plain);
        line_10->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_10);

        line_9 = new QFrame(tabScreen);
        line_9->setObjectName("line_9");
        line_9->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_9->setFrameShadow(QFrame::Plain);
        line_9->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_9);

        gridLayout_13 = new QGridLayout();
        gridLayout_13->setSpacing(6);
        gridLayout_13->setObjectName("gridLayout_13");
        gridLayout_13->setVerticalSpacing(0);
        toolButton_magnifier_rectangle = new QToolButton(tabScreen);
        buttonGroup_2 = new QButtonGroup(formMainWindow);
        buttonGroup_2->setObjectName("buttonGroup_2");
        buttonGroup_2->addButton(toolButton_magnifier_rectangle);
        toolButton_magnifier_rectangle->setObjectName("toolButton_magnifier_rectangle");
        toolButton_magnifier_rectangle->setText(QString::fromUtf8(""));
        toolButton_magnifier_rectangle->setCheckable(true);
        toolButton_magnifier_rectangle->setChecked(true);

        gridLayout_13->addWidget(toolButton_magnifier_rectangle, 1, 1, 1, 1);

        checkBoxMagnifier = new QCheckBox(tabScreen);
        checkBoxMagnifier->setObjectName("checkBoxMagnifier");
#if QT_CONFIG(tooltip)
        checkBoxMagnifier->setToolTip(QString::fromUtf8("CTRL+SHIFT+F9"));
#endif // QT_CONFIG(tooltip)

        gridLayout_13->addWidget(checkBoxMagnifier, 1, 0, 1, 1);

        help_screencast_magnifier = new QToolButton(tabScreen);
        help_screencast_magnifier->setObjectName("help_screencast_magnifier");
        help_screencast_magnifier->setText(QString::fromUtf8("Help"));

        gridLayout_13->addWidget(help_screencast_magnifier, 1, 3, 1, 1);

        label_magnifier_on_screen = new QLabel(tabScreen);
        label_magnifier_on_screen->setObjectName("label_magnifier_on_screen");
        label_magnifier_on_screen->setEnabled(false);
        label_magnifier_on_screen->setText(QString::fromUtf8("On Screen"));

        gridLayout_13->addWidget(label_magnifier_on_screen, 2, 0, 1, 1);

        horizontalLayout_60 = new QHBoxLayout();
        horizontalLayout_60->setSpacing(6);
        horizontalLayout_60->setObjectName("horizontalLayout_60");
        labelScreencastCountdownText = new QLabel(tabScreen);
        labelScreencastCountdownText->setObjectName("labelScreencastCountdownText");
        labelScreencastCountdownText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_60->addWidget(labelScreencastCountdownText);


        gridLayout_13->addLayout(horizontalLayout_60, 1, 5, 1, 2);

        toolButton_magnifier_elipse = new QToolButton(tabScreen);
        buttonGroup_2->addButton(toolButton_magnifier_elipse);
        toolButton_magnifier_elipse->setObjectName("toolButton_magnifier_elipse");
        toolButton_magnifier_elipse->setText(QString::fromUtf8(""));
        toolButton_magnifier_elipse->setCheckable(true);

        gridLayout_13->addWidget(toolButton_magnifier_elipse, 2, 1, 1, 1);

        line_11 = new QFrame(tabScreen);
        line_11->setObjectName("line_11");
        line_11->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_11->setFrameShadow(QFrame::Plain);
        line_11->setFrameShape(QFrame::Shape::VLine);

        gridLayout_13->addWidget(line_11, 1, 4, 3, 1);

        help_screencast_countdown = new QToolButton(tabScreen);
        help_screencast_countdown->setObjectName("help_screencast_countdown");
        help_screencast_countdown->setText(QString::fromUtf8("Help"));

        gridLayout_13->addWidget(help_screencast_countdown, 1, 7, 1, 1);

        horizontalLayout_rectangle = new QHBoxLayout();
        horizontalLayout_rectangle->setSpacing(6);
        horizontalLayout_rectangle->setObjectName("horizontalLayout_rectangle");
        horizontalLayout_rectangle->setContentsMargins(3, -1, -1, -1);

        gridLayout_13->addLayout(horizontalLayout_rectangle, 1, 2, 1, 1);

        toolButton_magnifier_circle = new QToolButton(tabScreen);
        buttonGroup_2->addButton(toolButton_magnifier_circle);
        toolButton_magnifier_circle->setObjectName("toolButton_magnifier_circle");
        toolButton_magnifier_circle->setText(QString::fromUtf8(""));
        toolButton_magnifier_circle->setCheckable(true);

        gridLayout_13->addWidget(toolButton_magnifier_circle, 3, 1, 1, 1);

        horizontalLayout_elipse = new QHBoxLayout();
        horizontalLayout_elipse->setSpacing(6);
        horizontalLayout_elipse->setObjectName("horizontalLayout_elipse");
        horizontalLayout_elipse->setContentsMargins(3, -1, -1, -1);

        gridLayout_13->addLayout(horizontalLayout_elipse, 2, 2, 1, 1);

        horizontalLayout_circle = new QHBoxLayout();
        horizontalLayout_circle->setSpacing(6);
        horizontalLayout_circle->setObjectName("horizontalLayout_circle");
        horizontalLayout_circle->setContentsMargins(3, -1, -1, -1);

        gridLayout_13->addLayout(horizontalLayout_circle, 3, 2, 1, 1);


        verticalLayout_7->addLayout(gridLayout_13);


        horizontalLayout_2->addLayout(verticalLayout_7);

        line_5 = new QFrame(tabScreen);
        line_5->setObjectName("line_5");
        line_5->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_5->setFrameShadow(QFrame::Plain);
        line_5->setFrameShape(QFrame::Shape::VLine);

        horizontalLayout_2->addWidget(line_5);

        gridLayout_6 = new QGridLayout();
        gridLayout_6->setSpacing(6);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setVerticalSpacing(0);
        gridLayout_6->setContentsMargins(-1, -1, -1, 10);
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setSpacing(6);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(-1, 10, -1, -1);
        label_25 = new QLabel(tabScreen);
        label_25->setObjectName("label_25");

        gridLayout_5->addWidget(label_25, 7, 1, 1, 1);

        labelInfoVideocodec = new QLabel(tabScreen);
        labelInfoVideocodec->setObjectName("labelInfoVideocodec");
        labelInfoVideocodec->setText(QString::fromUtf8(""));

        gridLayout_5->addWidget(labelInfoVideocodec, 6, 2, 1, 2);

        labelInfoFormat = new QLabel(tabScreen);
        labelInfoFormat->setObjectName("labelInfoFormat");
        labelInfoFormat->setText(QString::fromUtf8(""));

        gridLayout_5->addWidget(labelInfoFormat, 5, 2, 1, 2);

        label_14 = new QLabel(tabScreen);
        label_14->setObjectName("label_14");

        gridLayout_5->addWidget(label_14, 0, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_4, 9, 2, 1, 1);

        labelInfoAudiocodec = new QLabel(tabScreen);
        labelInfoAudiocodec->setObjectName("labelInfoAudiocodec");
        labelInfoAudiocodec->setText(QString::fromUtf8(""));

        gridLayout_5->addWidget(labelInfoAudiocodec, 7, 2, 1, 2);

        label_16 = new QLabel(tabScreen);
        label_16->setObjectName("label_16");
        label_16->setText(QString::fromUtf8("KB"));

        gridLayout_5->addWidget(label_16, 2, 3, 1, 1);

        line_3 = new QFrame(tabScreen);
        line_3->setObjectName("line_3");
        line_3->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_3->setFrameShadow(QFrame::Plain);
        line_3->setFrameShape(QFrame::Shape::HLine);

        gridLayout_5->addWidget(line_3, 4, 1, 1, 3);

        label_15 = new QLabel(tabScreen);
        label_15->setObjectName("label_15");
        label_15->setText(QString::fromUtf8("MB"));

        gridLayout_5->addWidget(label_15, 1, 3, 1, 1);

        label_12 = new QLabel(tabScreen);
        label_12->setObjectName("label_12");

        gridLayout_5->addWidget(label_12, 1, 1, 1, 1);

        label_23 = new QLabel(tabScreen);
        label_23->setObjectName("label_23");

        gridLayout_5->addWidget(label_23, 5, 1, 1, 1);

        labelInfoRecordTime = new QLabel(tabScreen);
        labelInfoRecordTime->setObjectName("labelInfoRecordTime");
        labelInfoRecordTime->setText(QString::fromUtf8("00:00:00"));
        labelInfoRecordTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(labelInfoRecordTime, 0, 2, 1, 2);

        label_24 = new QLabel(tabScreen);
        label_24->setObjectName("label_24");

        gridLayout_5->addWidget(label_24, 6, 1, 1, 1);

        labelFreeSize = new QLabel(tabScreen);
        labelFreeSize->setObjectName("labelFreeSize");
        labelFreeSize->setMinimumSize(QSize(40, 0));
        labelFreeSize->setText(QString::fromUtf8("0"));
        labelFreeSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(labelFreeSize, 1, 2, 1, 1);

        label_29 = new QLabel(tabScreen);
        label_29->setObjectName("label_29");

        gridLayout_5->addWidget(label_29, 8, 1, 1, 1);

        labelVideoSize = new QLabel(tabScreen);
        labelVideoSize->setObjectName("labelVideoSize");
        labelVideoSize->setText(QString::fromUtf8("0"));
        labelVideoSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(labelVideoSize, 2, 2, 1, 1);

        label_13 = new QLabel(tabScreen);
        label_13->setObjectName("label_13");

        gridLayout_5->addWidget(label_13, 2, 1, 1, 1);

        labelInfoFrames = new QLabel(tabScreen);
        labelInfoFrames->setObjectName("labelInfoFrames");
        labelInfoFrames->setText(QString::fromUtf8(""));

        gridLayout_5->addWidget(labelInfoFrames, 8, 2, 1, 2);


        gridLayout_6->addLayout(gridLayout_5, 1, 0, 1, 1);

        verticalSpacer_21 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_21, 3, 0, 1, 1);

        label_Upate_tab_1 = new QLabel(tabScreen);
        label_Upate_tab_1->setObjectName("label_Upate_tab_1");
        label_Upate_tab_1->setText(QString::fromUtf8("TextLabel"));
        label_Upate_tab_1->setOpenExternalLinks(true);

        gridLayout_6->addWidget(label_Upate_tab_1, 2, 0, 1, 1, Qt::AlignHCenter);

        label_17 = new QLabel(tabScreen);
        label_17->setObjectName("label_17");

        gridLayout_6->addWidget(label_17, 0, 0, 1, 1, Qt::AlignHCenter);


        horizontalLayout_2->addLayout(gridLayout_6);

        tabWidgetScreencast->addTab(tabScreen, icon, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabScreen), QString::fromUtf8(""));
        tabVideo = new QWidget();
        tabVideo->setObjectName("tabVideo");
        widget = new QWidget(tabVideo);
        widget->setObjectName("widget");
        widget->setGeometry(QRect(50, 30, 505, 291));
        verticalLayout_4 = new QVBoxLayout(widget);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setContentsMargins(11, 11, 11, 11);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        gridLayoutFormatCodecs = new QGridLayout();
        gridLayoutFormatCodecs->setSpacing(6);
        gridLayoutFormatCodecs->setObjectName("gridLayoutFormatCodecs");
        frameVideoCodecQuality = new QFrame(widget);
        frameVideoCodecQuality->setObjectName("frameVideoCodecQuality");
        frameVideoCodecQuality->setFrameShape(QFrame::NoFrame);
        frameVideoCodecQuality->setFrameShadow(QFrame::Raised);
        verticalLayout_9 = new QVBoxLayout(frameVideoCodecQuality);
        verticalLayout_9->setSpacing(10);
        verticalLayout_9->setContentsMargins(11, 11, 11, 11);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(0, 0, 0, 0);
        frameVideoCodecx264 = new QFrame(frameVideoCodecQuality);
        frameVideoCodecx264->setObjectName("frameVideoCodecx264");
        frameVideoCodecx264->setFrameShape(QFrame::NoFrame);
        horizontalLayout_x264 = new QHBoxLayout(frameVideoCodecx264);
        horizontalLayout_x264->setSpacing(6);
        horizontalLayout_x264->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_x264->setObjectName("horizontalLayout_x264");
        horizontalLayout_x264->setContentsMargins(6, 0, 0, 0);
        verticalLayout_19 = new QVBoxLayout();
        verticalLayout_19->setSpacing(0);
        verticalLayout_19->setObjectName("verticalLayout_19");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        comboBoxx264Preset = new QComboBox(frameVideoCodecx264);
        comboBoxx264Preset->addItem(QString::fromUtf8("ultrafast"));
        comboBoxx264Preset->addItem(QString::fromUtf8("superfast"));
        comboBoxx264Preset->addItem(QString::fromUtf8("veryfast"));
        comboBoxx264Preset->addItem(QString::fromUtf8("faster"));
        comboBoxx264Preset->addItem(QString::fromUtf8("fast"));
        comboBoxx264Preset->addItem(QString::fromUtf8("medium"));
        comboBoxx264Preset->setObjectName("comboBoxx264Preset");
        comboBoxx264Preset->setCurrentText(QString::fromUtf8("superfast"));
        comboBoxx264Preset->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_3->addWidget(comboBoxx264Preset);

        comboBoxx264Profile = new QComboBox(frameVideoCodecx264);
        comboBoxx264Profile->addItem(QString::fromUtf8("baseline"));
        comboBoxx264Profile->addItem(QString::fromUtf8("high-4:4:4"));
        comboBoxx264Profile->setObjectName("comboBoxx264Profile");
        comboBoxx264Profile->setCurrentText(QString::fromUtf8("baseline"));
        comboBoxx264Profile->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_3->addWidget(comboBoxx264Profile);


        verticalLayout_19->addLayout(horizontalLayout_3);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setSpacing(6);
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        label_21 = new QLabel(frameVideoCodecx264);
        label_21->setObjectName("label_21");
        label_21->setMaximumSize(QSize(28, 28));
        label_21->setText(QString::fromUtf8(""));
        label_21->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/compress.png")));
        label_21->setScaledContents(true);

        horizontalLayout_26->addWidget(label_21);


        verticalLayout_19->addLayout(horizontalLayout_26);


        horizontalLayout_x264->addLayout(verticalLayout_19);

        toolButtonx264Reset = new QToolButton(frameVideoCodecx264);
        toolButtonx264Reset->setObjectName("toolButtonx264Reset");
        toolButtonx264Reset->setText(QString::fromUtf8(""));
        toolButtonx264Reset->setIcon(icon7);

        horizontalLayout_x264->addWidget(toolButtonx264Reset, 0, Qt::AlignTop);


        verticalLayout_9->addWidget(frameVideoCodecx264, 0, Qt::AlignTop);

        frameVideoCodecOpenh264 = new QFrame(frameVideoCodecQuality);
        frameVideoCodecOpenh264->setObjectName("frameVideoCodecOpenh264");
        frameVideoCodecOpenh264->setFrameShape(QFrame::NoFrame);
        horizontalLayout_64 = new QHBoxLayout(frameVideoCodecOpenh264);
        horizontalLayout_64->setSpacing(6);
        horizontalLayout_64->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_64->setObjectName("horizontalLayout_64");
        horizontalLayout_64->setContentsMargins(6, 0, 0, 0);
        verticalLayout_40 = new QVBoxLayout();
        verticalLayout_40->setSpacing(0);
        verticalLayout_40->setObjectName("verticalLayout_40");
        horizontalLayout_67 = new QHBoxLayout();
        horizontalLayout_67->setSpacing(6);
        horizontalLayout_67->setObjectName("horizontalLayout_67");
        label_61 = new QLabel(frameVideoCodecOpenh264);
        label_61->setObjectName("label_61");
        label_61->setText(QString::fromUtf8("Profile"));

        horizontalLayout_67->addWidget(label_61);

        comboBox_openh264_profile = new QComboBox(frameVideoCodecOpenh264);
        comboBox_openh264_profile->setObjectName("comboBox_openh264_profile");
        comboBox_openh264_profile->setCurrentText(QString::fromUtf8(""));

        horizontalLayout_67->addWidget(comboBox_openh264_profile);

        horizontalLayout_67->setStretch(1, 1);

        verticalLayout_40->addLayout(horizontalLayout_67);

        horizontalLayout_openh264 = new QHBoxLayout();
        horizontalLayout_openh264->setSpacing(6);
        horizontalLayout_openh264->setObjectName("horizontalLayout_openh264");
        label_19 = new QLabel(frameVideoCodecOpenh264);
        label_19->setObjectName("label_19");
        label_19->setMinimumSize(QSize(0, 0));
        label_19->setMaximumSize(QSize(28, 28));
        label_19->setText(QString::fromUtf8(""));
        label_19->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/compress.png")));
        label_19->setScaledContents(true);

        horizontalLayout_openh264->addWidget(label_19);


        verticalLayout_40->addLayout(horizontalLayout_openh264);


        horizontalLayout_64->addLayout(verticalLayout_40);

        toolButtonOpenh264Reset = new QToolButton(frameVideoCodecOpenh264);
        toolButtonOpenh264Reset->setObjectName("toolButtonOpenh264Reset");
        toolButtonOpenh264Reset->setText(QString::fromUtf8(""));
        toolButtonOpenh264Reset->setIcon(icon7);

        horizontalLayout_64->addWidget(toolButtonOpenh264Reset, 0, Qt::AlignTop);


        verticalLayout_9->addWidget(frameVideoCodecOpenh264, 0, Qt::AlignTop);

        frameVideoCodecGIF = new QFrame(frameVideoCodecQuality);
        frameVideoCodecGIF->setObjectName("frameVideoCodecGIF");
        frameVideoCodecGIF->setFrameShape(QFrame::NoFrame);
        horizontalLayout_62 = new QHBoxLayout(frameVideoCodecGIF);
        horizontalLayout_62->setSpacing(6);
        horizontalLayout_62->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_62->setObjectName("horizontalLayout_62");
        horizontalLayout_62->setContentsMargins(6, 0, 6, 0);
        checkBoxGifLoop = new QCheckBox(frameVideoCodecGIF);
        checkBoxGifLoop->setObjectName("checkBoxGifLoop");
        checkBoxGifLoop->setText(QString::fromUtf8(""));
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/pictures/screencast/loop.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        checkBoxGifLoop->setIcon(icon9);
        checkBoxGifLoop->setIconSize(QSize(32, 32));

        horizontalLayout_62->addWidget(checkBoxGifLoop, 0, Qt::AlignTop);


        verticalLayout_9->addWidget(frameVideoCodecGIF, 0, Qt::AlignTop);


        gridLayoutFormatCodecs->addWidget(frameVideoCodecQuality, 2, 2, 1, 1);

        comboBoxFormat = new QComboBox(widget);
        comboBoxFormat->setObjectName("comboBoxFormat");
        comboBoxFormat->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayoutFormatCodecs->addWidget(comboBoxFormat, 1, 1, 1, 1);

        labelFormat = new QLabel(widget);
        labelFormat->setObjectName("labelFormat");
        labelFormat->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutFormatCodecs->addWidget(labelFormat, 1, 0, 1, 1, Qt::AlignLeft);

        comboBoxVideoCodec = new QComboBox(widget);
        comboBoxVideoCodec->setObjectName("comboBoxVideoCodec");
        comboBoxVideoCodec->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        comboBoxVideoCodec->setMinimumContentsLength(14);

        gridLayoutFormatCodecs->addWidget(comboBoxVideoCodec, 2, 1, 1, 1, Qt::AlignTop);

        frameFrames = new QFrame(widget);
        frameFrames->setObjectName("frameFrames");
        frameFrames->setFrameShape(QFrame::NoFrame);
        frameFrames->setFrameShadow(QFrame::Raised);
        horizontalLayout_33 = new QHBoxLayout(frameFrames);
        horizontalLayout_33->setSpacing(6);
        horizontalLayout_33->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_33->setObjectName("horizontalLayout_33");
        horizontalLayout_33->setContentsMargins(0, 0, 0, 0);
        toolButtonFramesReset = new QToolButton(frameFrames);
        toolButtonFramesReset->setObjectName("toolButtonFramesReset");
        toolButtonFramesReset->setText(QString::fromUtf8(""));
        toolButtonFramesReset->setIcon(icon7);

        horizontalLayout_33->addWidget(toolButtonFramesReset);

        help_screencast_frames = new QToolButton(frameFrames);
        help_screencast_frames->setObjectName("help_screencast_frames");
        help_screencast_frames->setText(QString::fromUtf8("Help"));

        horizontalLayout_33->addWidget(help_screencast_frames);

        horizontalSpacer_42 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_33->addItem(horizontalSpacer_42);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setSpacing(6);
        horizontalLayout_22->setObjectName("horizontalLayout_22");
        checkBoxMouseCursorOnOff = new QCheckBox(frameFrames);
        checkBoxMouseCursorOnOff->setObjectName("checkBoxMouseCursorOnOff");

        horizontalLayout_22->addWidget(checkBoxMouseCursorOnOff);


        horizontalLayout_33->addLayout(horizontalLayout_22);


        gridLayoutFormatCodecs->addWidget(frameFrames, 0, 1, 1, 2);

        verticalLayout_22 = new QVBoxLayout();
        verticalLayout_22->setSpacing(6);
        verticalLayout_22->setObjectName("verticalLayout_22");
        verticalLayout_22->setContentsMargins(-1, 6, -1, -1);
        labelVideoCodec = new QLabel(widget);
        labelVideoCodec->setObjectName("labelVideoCodec");

        verticalLayout_22->addWidget(labelVideoCodec, 0, Qt::AlignTop);


        gridLayoutFormatCodecs->addLayout(verticalLayout_22, 2, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayoutFormatCodecs->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        help_screencast_nomousecursor = new QToolButton(widget);
        help_screencast_nomousecursor->setObjectName("help_screencast_nomousecursor");
        help_screencast_nomousecursor->setText(QString::fromUtf8("Help"));

        gridLayoutFormatCodecs->addWidget(help_screencast_nomousecursor, 0, 3, 1, 1);

        labelFrames = new QLabel(widget);
        labelFrames->setObjectName("labelFrames");
        labelFrames->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutFormatCodecs->addWidget(labelFrames, 0, 0, 1, 1, Qt::AlignLeft);

        help_screencast_videocodec = new QToolButton(widget);
        help_screencast_videocodec->setObjectName("help_screencast_videocodec");
        help_screencast_videocodec->setText(QString::fromUtf8("Help"));

        gridLayoutFormatCodecs->addWidget(help_screencast_videocodec, 2, 3, 1, 1, Qt::AlignTop);

        help_screencast_format = new QToolButton(widget);
        help_screencast_format->setObjectName("help_screencast_format");
        help_screencast_format->setText(QString::fromUtf8("Help"));

        gridLayoutFormatCodecs->addWidget(help_screencast_format, 1, 3, 1, 1);


        verticalLayout_4->addLayout(gridLayoutFormatCodecs);

        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/pictures/screencast/format-codec.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabVideo, icon10, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabVideo), QString::fromUtf8(""));
        tabMisc = new QWidget();
        tabMisc->setObjectName("tabMisc");
        verticalLayout_2 = new QVBoxLayout(tabMisc);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout_8 = new QGridLayout();
        gridLayout_8->setSpacing(6);
        gridLayout_8->setObjectName("gridLayout_8");
        verticalSpacer_23 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_23, 10, 0, 1, 1);

        verticalSpacer_14 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_14, 8, 0, 1, 1);

        help_screencast_limitoffreediskspace = new QToolButton(tabMisc);
        help_screencast_limitoffreediskspace->setObjectName("help_screencast_limitoffreediskspace");
        help_screencast_limitoffreediskspace->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_limitoffreediskspace, 1, 2, 1, 1);

        help_screencast_SecondWaitBeforeRecording = new QToolButton(tabMisc);
        help_screencast_SecondWaitBeforeRecording->setObjectName("help_screencast_SecondWaitBeforeRecording");
        help_screencast_SecondWaitBeforeRecording->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_SecondWaitBeforeRecording, 5, 2, 1, 1);

        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setSpacing(6);
        horizontalLayout_25->setObjectName("horizontalLayout_25");
        frameVideoPath = new QFrame(tabMisc);
        frameVideoPath->setObjectName("frameVideoPath");
        frameVideoPath->setFrameShape(QFrame::NoFrame);
        frameVideoPath->setFrameShadow(QFrame::Raised);
        horizontalLayout_20 = new QHBoxLayout(frameVideoPath);
        horizontalLayout_20->setSpacing(6);
        horizontalLayout_20->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        horizontalLayout_20->setContentsMargins(0, 0, -1, 0);
        LabelVideoPath = new QLabel(frameVideoPath);
        LabelVideoPath->setObjectName("LabelVideoPath");

        horizontalLayout_20->addWidget(LabelVideoPath);

        lineEditVideoPath = new QLineEdit(frameVideoPath);
        lineEditVideoPath->setObjectName("lineEditVideoPath");
        lineEditVideoPath->setText(QString::fromUtf8(""));
        lineEditVideoPath->setReadOnly(true);

        horizontalLayout_20->addWidget(lineEditVideoPath);

        toolButtonVideoPath = new QToolButton(frameVideoPath);
        toolButtonVideoPath->setObjectName("toolButtonVideoPath");
        toolButtonVideoPath->setText(QString::fromUtf8("..."));

        horizontalLayout_20->addWidget(toolButtonVideoPath);


        horizontalLayout_25->addWidget(frameVideoPath);


        gridLayout_8->addLayout(horizontalLayout_25, 0, 0, 1, 1);

        gridLayout_14 = new QGridLayout();
        gridLayout_14->setSpacing(6);
        gridLayout_14->setObjectName("gridLayout_14");
        horizontalSpacer_52 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_14->addItem(horizontalSpacer_52, 0, 3, 1, 1);

        label_20 = new QLabel(tabMisc);
        label_20->setObjectName("label_20");
        label_20->setMaximumSize(QSize(24, 24));
        label_20->setText(QString::fromUtf8(""));
        label_20->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/information.png")));
        label_20->setScaledContents(true);

        gridLayout_14->addWidget(label_20, 0, 4, 1, 1);

        comboBoxLanguage = new QComboBox(tabMisc);
        comboBoxLanguage->setObjectName("comboBoxLanguage");
        comboBoxLanguage->setEditable(true);
        comboBoxLanguage->setCurrentText(QString::fromUtf8(""));
        comboBoxLanguage->setMaxVisibleItems(12);
        comboBoxLanguage->setPlaceholderText(QString::fromUtf8(""));

        gridLayout_14->addWidget(comboBoxLanguage, 0, 1, 1, 1);

        horizontalSpacer_29 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_14->addItem(horizontalSpacer_29, 0, 6, 1, 1);

        comboBoxOnlineHelp = new QComboBox(tabMisc);
        comboBoxOnlineHelp->addItem(QString());
        comboBoxOnlineHelp->setObjectName("comboBoxOnlineHelp");
        comboBoxOnlineHelp->setCurrentText(QString::fromUtf8("Automatically"));
        comboBoxOnlineHelp->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_14->addWidget(comboBoxOnlineHelp, 0, 5, 1, 1);

        label_66 = new QLabel(tabMisc);
        label_66->setObjectName("label_66");
        label_66->setMaximumSize(QSize(28, 28));
        label_66->setText(QString::fromUtf8(""));
        label_66->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/world.png")));
        label_66->setScaledContents(true);

        gridLayout_14->addWidget(label_66, 0, 0, 1, 1);


        gridLayout_8->addLayout(gridLayout_14, 7, 0, 1, 1);

        help_screencast_startsminimized = new QToolButton(tabMisc);
        help_screencast_startsminimized->setObjectName("help_screencast_startsminimized");
        help_screencast_startsminimized->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_startsminimized, 4, 2, 1, 1);

        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setSpacing(6);
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        frameShowInSystray = new QFrame(tabMisc);
        frameShowInSystray->setObjectName("frameShowInSystray");
        frameShowInSystray->setFrameShape(QFrame::NoFrame);
        frameShowInSystray->setFrameShadow(QFrame::Raised);
        horizontalLayout_30 = new QHBoxLayout(frameShowInSystray);
        horizontalLayout_30->setSpacing(0);
        horizontalLayout_30->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_30->setObjectName("horizontalLayout_30");
        horizontalLayout_30->setContentsMargins(0, 0, 0, 0);
        checkBoxShowInSystray = new QCheckBox(frameShowInSystray);
        checkBoxShowInSystray->setObjectName("checkBoxShowInSystray");

        horizontalLayout_30->addWidget(checkBoxShowInSystray);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_30->addItem(horizontalSpacer_8);


        horizontalLayout_21->addWidget(frameShowInSystray);

        frameShowInSystrayAlternative = new QFrame(tabMisc);
        frameShowInSystrayAlternative->setObjectName("frameShowInSystrayAlternative");
        frameShowInSystrayAlternative->setFrameShape(QFrame::NoFrame);
        frameShowInSystrayAlternative->setFrameShadow(QFrame::Raised);
        horizontalLayout_18 = new QHBoxLayout(frameShowInSystrayAlternative);
        horizontalLayout_18->setSpacing(0);
        horizontalLayout_18->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalLayout_18->setContentsMargins(0, 0, 0, 0);
        checkBoxShowInSystrayAlternative = new QCheckBox(frameShowInSystrayAlternative);
        checkBoxShowInSystrayAlternative->setObjectName("checkBoxShowInSystrayAlternative");

        horizontalLayout_18->addWidget(checkBoxShowInSystrayAlternative);


        horizontalLayout_21->addWidget(frameShowInSystrayAlternative);


        gridLayout_8->addLayout(horizontalLayout_21, 2, 0, 1, 1);

        help_screencast_deleteallsettings = new QToolButton(tabMisc);
        help_screencast_deleteallsettings->setObjectName("help_screencast_deleteallsettings");
        help_screencast_deleteallsettings->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_deleteallsettings, 15, 2, 1, 1);

        horizontalLayout_31 = new QHBoxLayout();
        horizontalLayout_31->setSpacing(6);
        horizontalLayout_31->setObjectName("horizontalLayout_31");
        checkBoxStartsMinimized = new QCheckBox(tabMisc);
        checkBoxStartsMinimized->setObjectName("checkBoxStartsMinimized");

        horizontalLayout_31->addWidget(checkBoxStartsMinimized);


        gridLayout_8->addLayout(horizontalLayout_31, 4, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer, 6, 0, 1, 1);

        horizontalLayout_28 = new QHBoxLayout();
        horizontalLayout_28->setSpacing(6);
        horizontalLayout_28->setObjectName("horizontalLayout_28");
        frameLimitOfFreeDiskSpace = new QFrame(tabMisc);
        frameLimitOfFreeDiskSpace->setObjectName("frameLimitOfFreeDiskSpace");
        frameLimitOfFreeDiskSpace->setFrameShape(QFrame::NoFrame);
        frameLimitOfFreeDiskSpace->setFrameShadow(QFrame::Raised);
        horizontalLayout_27 = new QHBoxLayout(frameLimitOfFreeDiskSpace);
        horizontalLayout_27->setSpacing(6);
        horizontalLayout_27->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_27->setObjectName("horizontalLayout_27");
        horizontalLayout_27->setContentsMargins(0, 0, -1, 0);
        label_10 = new QLabel(frameLimitOfFreeDiskSpace);
        label_10->setObjectName("label_10");

        horizontalLayout_27->addWidget(label_10);

        label_11 = new QLabel(frameLimitOfFreeDiskSpace);
        label_11->setObjectName("label_11");

        horizontalLayout_27->addWidget(label_11);


        horizontalLayout_28->addWidget(frameLimitOfFreeDiskSpace);


        gridLayout_8->addLayout(horizontalLayout_28, 1, 0, 1, 1);

        help_screencast_lookforupdates = new QToolButton(tabMisc);
        help_screencast_lookforupdates->setObjectName("help_screencast_lookforupdates");

        gridLayout_8->addWidget(help_screencast_lookforupdates, 13, 2, 1, 1);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setSpacing(6);
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        checkBoxMinimizedWhenRecordingStarts = new QCheckBox(tabMisc);
        checkBoxMinimizedWhenRecordingStarts->setObjectName("checkBoxMinimizedWhenRecordingStarts");

        horizontalLayout_23->addWidget(checkBoxMinimizedWhenRecordingStarts);


        gridLayout_8->addLayout(horizontalLayout_23, 3, 0, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setSpacing(6);
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        checkBoxLookForUpdates = new QCheckBox(tabMisc);
        checkBoxLookForUpdates->setObjectName("checkBoxLookForUpdates");

        horizontalLayout_17->addWidget(checkBoxLookForUpdates);

        label_Upate_tab_4 = new QLabel(tabMisc);
        label_Upate_tab_4->setObjectName("label_Upate_tab_4");
        label_Upate_tab_4->setText(QString::fromUtf8("TextLabel"));
        label_Upate_tab_4->setOpenExternalLinks(true);

        horizontalLayout_17->addWidget(label_Upate_tab_4);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_3);


        gridLayout_8->addLayout(horizontalLayout_17, 13, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(-1, -1, 9, -1);
        label_18 = new QLabel(tabMisc);
        label_18->setObjectName("label_18");

        horizontalLayout_7->addWidget(label_18);

        horizontalSpacer_44 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_44);


        gridLayout_8->addLayout(horizontalLayout_7, 5, 0, 1, 1);

        help_screencast_showinsystray = new QToolButton(tabMisc);
        help_screencast_showinsystray->setObjectName("help_screencast_showinsystray");
        help_screencast_showinsystray->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_showinsystray, 2, 2, 1, 1);

        checkBoxResetAtNextStart = new QCheckBox(tabMisc);
        checkBoxResetAtNextStart->setObjectName("checkBoxResetAtNextStart");

        gridLayout_8->addWidget(checkBoxResetAtNextStart, 15, 0, 1, 1);

        horizontalLayout_darkMode = new QHBoxLayout();
        horizontalLayout_darkMode->setSpacing(6);
        horizontalLayout_darkMode->setObjectName("horizontalLayout_darkMode");
        label_65 = new QLabel(tabMisc);
        label_65->setObjectName("label_65");
        label_65->setMaximumSize(QSize(28, 28));
        label_65->setText(QString::fromUtf8(""));
        label_65->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/day.png")));
        label_65->setScaledContents(true);

        horizontalLayout_darkMode->addWidget(label_65);

        label_63 = new QLabel(tabMisc);
        label_63->setObjectName("label_63");
        label_63->setMaximumSize(QSize(15, 24));
        label_63->setText(QString::fromUtf8(""));
        label_63->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/night.png")));
        label_63->setScaledContents(true);

        horizontalLayout_darkMode->addWidget(label_63);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_darkMode->addItem(horizontalSpacer_12);


        gridLayout_8->addLayout(horizontalLayout_darkMode, 9, 0, 1, 1);

        help_screencast_videopath = new QToolButton(tabMisc);
        help_screencast_videopath->setObjectName("help_screencast_videopath");
        help_screencast_videopath->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_videopath, 0, 2, 1, 1);

        toolButtonShowInSystrayAlternativeReset = new QToolButton(tabMisc);
        toolButtonShowInSystrayAlternativeReset->setObjectName("toolButtonShowInSystrayAlternativeReset");
        toolButtonShowInSystrayAlternativeReset->setText(QString::fromUtf8(""));
        toolButtonShowInSystrayAlternativeReset->setIcon(icon7);

        gridLayout_8->addWidget(toolButtonShowInSystrayAlternativeReset, 2, 1, 1, 1);

        help_screencast_minimizedwhenrecordingstarts = new QToolButton(tabMisc);
        help_screencast_minimizedwhenrecordingstarts->setObjectName("help_screencast_minimizedwhenrecordingstarts");
        help_screencast_minimizedwhenrecordingstarts->setText(QString::fromUtf8("Help"));

        gridLayout_8->addWidget(help_screencast_minimizedwhenrecordingstarts, 3, 2, 1, 1);

        horizontalLayout_36 = new QHBoxLayout();
        horizontalLayout_36->setSpacing(6);
        horizontalLayout_36->setObjectName("horizontalLayout_36");
        checkBoxGstreamerDebugLevel = new QCheckBox(tabMisc);
        checkBoxGstreamerDebugLevel->setObjectName("checkBoxGstreamerDebugLevel");
        checkBoxGstreamerDebugLevel->setText(QString::fromUtf8("GStreamer Debuglevel"));

        horizontalLayout_36->addWidget(checkBoxGstreamerDebugLevel);

        pushButtonGstreamerDebugLevel = new QPushButton(tabMisc);
        pushButtonGstreamerDebugLevel->setObjectName("pushButtonGstreamerDebugLevel");

        horizontalLayout_36->addWidget(pushButtonGstreamerDebugLevel);

        horizontalSpacer_46 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_36->addItem(horizontalSpacer_46);


        gridLayout_8->addLayout(horizontalLayout_36, 14, 0, 1, 1);

        help_screencast_gstreamerDebugLevel = new QToolButton(tabMisc);
        help_screencast_gstreamerDebugLevel->setObjectName("help_screencast_gstreamerDebugLevel");

        gridLayout_8->addWidget(help_screencast_gstreamerDebugLevel, 14, 2, 1, 1);

        frameProfile = new QFrame(tabMisc);
        frameProfile->setObjectName("frameProfile");
        frameProfile->setFrameShape(QFrame::NoFrame);
        frameProfile->setFrameShadow(QFrame::Raised);
        horizontalLayout_13 = new QHBoxLayout(frameProfile);
        horizontalLayout_13->setSpacing(6);
        horizontalLayout_13->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalLayout_13->setContentsMargins(0, 0, 0, 0);
        labelProfile = new QLabel(frameProfile);
        labelProfile->setObjectName("labelProfile");
        labelProfile->setMaximumSize(QSize(24, 24));
        labelProfile->setText(QString::fromUtf8(""));
        labelProfile->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/profile.png")));
        labelProfile->setScaledContents(true);
        labelProfile->setWordWrap(false);

        horizontalLayout_13->addWidget(labelProfile);

        comboBoxProfile = new QComboBox(frameProfile);
        comboBoxProfile->setObjectName("comboBoxProfile");
        comboBoxProfile->setMinimumSize(QSize(114, 0));
        comboBoxProfile->setCurrentText(QString::fromUtf8(""));
        comboBoxProfile->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        horizontalLayout_13->addWidget(comboBoxProfile);

        pushButtonProfileSave = new QPushButton(frameProfile);
        pushButtonProfileSave->setObjectName("pushButtonProfileSave");
        pushButtonProfileSave->setEnabled(false);
#if QT_CONFIG(tooltip)
        pushButtonProfileSave->setToolTip(QString::fromUtf8("Save"));
#endif // QT_CONFIG(tooltip)
        pushButtonProfileSave->setText(QString::fromUtf8(""));
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/pictures/screencast/profile-save.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushButtonProfileSave->setIcon(icon11);
        pushButtonProfileSave->setIconSize(QSize(20, 20));

        horizontalLayout_13->addWidget(pushButtonProfileSave);

        pushButtonProfileNew = new QPushButton(frameProfile);
        pushButtonProfileNew->setObjectName("pushButtonProfileNew");
#if QT_CONFIG(tooltip)
        pushButtonProfileNew->setToolTip(QString::fromUtf8("New"));
#endif // QT_CONFIG(tooltip)
        pushButtonProfileNew->setText(QString::fromUtf8(""));
        QIcon icon12;
        icon12.addFile(QString::fromUtf8(":/pictures/screencast/profile-new.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushButtonProfileNew->setIcon(icon12);
        pushButtonProfileNew->setIconSize(QSize(20, 20));

        horizontalLayout_13->addWidget(pushButtonProfileNew);

        pushButtonProfileDelete = new QPushButton(frameProfile);
        pushButtonProfileDelete->setObjectName("pushButtonProfileDelete");
        pushButtonProfileDelete->setEnabled(false);
#if QT_CONFIG(tooltip)
        pushButtonProfileDelete->setToolTip(QString::fromUtf8("Delete"));
#endif // QT_CONFIG(tooltip)
        pushButtonProfileDelete->setText(QString::fromUtf8(""));
        QIcon icon13;
        icon13.addFile(QString::fromUtf8(":/pictures/screencast/profile-delete.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushButtonProfileDelete->setIcon(icon13);
        pushButtonProfileDelete->setIconSize(QSize(20, 20));

        horizontalLayout_13->addWidget(pushButtonProfileDelete);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer);


        gridLayout_8->addWidget(frameProfile, 11, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_5, 12, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_8);

        QIcon icon14;
        icon14.addFile(QString::fromUtf8(":/pictures/screencast/preferences-system.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabMisc, icon14, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabMisc), QString::fromUtf8(""));
        tabTimer = new QWidget();
        tabTimer->setObjectName("tabTimer");
        verticalLayout_23 = new QVBoxLayout(tabTimer);
        verticalLayout_23->setSpacing(6);
        verticalLayout_23->setContentsMargins(11, 11, 11, 11);
        verticalLayout_23->setObjectName("verticalLayout_23");
        horizontalLayout_29 = new QHBoxLayout();
        horizontalLayout_29->setSpacing(6);
        horizontalLayout_29->setObjectName("horizontalLayout_29");
        frameStartTime = new QFrame(tabTimer);
        frameStartTime->setObjectName("frameStartTime");
        frameStartTime->setEnabled(true);
        frameStartTime->setFrameShape(QFrame::NoFrame);
        frameStartTime->setFrameShadow(QFrame::Raised);
        horizontalLayout_24 = new QHBoxLayout(frameStartTime);
        horizontalLayout_24->setSpacing(6);
        horizontalLayout_24->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_24->setObjectName("horizontalLayout_24");
        horizontalLayout_24->setContentsMargins(0, 0, 0, 0);
        verticalLayout_18 = new QVBoxLayout();
        verticalLayout_18->setSpacing(6);
        verticalLayout_18->setObjectName("verticalLayout_18");
        labelHour = new QLabel(frameStartTime);
        labelHour->setObjectName("labelHour");

        verticalLayout_18->addWidget(labelHour, 0, Qt::AlignRight);

        labelMinute = new QLabel(frameStartTime);
        labelMinute->setObjectName("labelMinute");
        labelMinute->setMidLineWidth(8);
        labelMinute->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout_18->addWidget(labelMinute, 0, Qt::AlignRight);


        horizontalLayout_24->addLayout(verticalLayout_18);

        verticalLayout_14 = new QVBoxLayout();
        verticalLayout_14->setSpacing(6);
        verticalLayout_14->setObjectName("verticalLayout_14");

        horizontalLayout_24->addLayout(verticalLayout_14);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_24->addItem(horizontalSpacer_9);

        horizontalLayout_46 = new QHBoxLayout();
        horizontalLayout_46->setSpacing(6);
        horizontalLayout_46->setObjectName("horizontalLayout_46");
        checkBoxStartTime = new QCheckBox(frameStartTime);
        checkBoxStartTime->setObjectName("checkBoxStartTime");

        horizontalLayout_46->addWidget(checkBoxStartTime);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_46->addItem(horizontalSpacer_17);


        horizontalLayout_24->addLayout(horizontalLayout_46);

        horizontalLayout_24->setStretch(1, 1);

        horizontalLayout_29->addWidget(frameStartTime);

        help_screencast_starttimer = new QToolButton(tabTimer);
        help_screencast_starttimer->setObjectName("help_screencast_starttimer");
#if QT_CONFIG(tooltip)
        help_screencast_starttimer->setToolTip(QString::fromUtf8("Help"));
#endif // QT_CONFIG(tooltip)
        help_screencast_starttimer->setText(QString::fromUtf8("Help"));

        horizontalLayout_29->addWidget(help_screencast_starttimer, 0, Qt::AlignTop);


        verticalLayout_23->addLayout(horizontalLayout_29);

        line = new QFrame(tabTimer);
        line->setObjectName("line");
        line->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line->setFrameShadow(QFrame::Plain);
        line->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_23->addWidget(line);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setSpacing(6);
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        checkBoxStopRecordingAfter = new QCheckBox(tabTimer);
        checkBoxStopRecordingAfter->setObjectName("checkBoxStopRecordingAfter");
        checkBoxStopRecordingAfter->setEnabled(true);

        horizontalLayout_19->addWidget(checkBoxStopRecordingAfter);

        frameStopRecordingAfter = new QFrame(tabTimer);
        frameStopRecordingAfter->setObjectName("frameStopRecordingAfter");
        frameStopRecordingAfter->setEnabled(false);
        frameStopRecordingAfter->setFrameShape(QFrame::NoFrame);
        frameStopRecordingAfter->setFrameShadow(QFrame::Raised);
        horizontalLayout_16 = new QHBoxLayout(frameStopRecordingAfter);
        horizontalLayout_16->setSpacing(6);
        horizontalLayout_16->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        horizontalLayout_16->setContentsMargins(0, 0, 0, 0);
        verticalLayout_30 = new QVBoxLayout();
        verticalLayout_30->setSpacing(6);
        verticalLayout_30->setObjectName("verticalLayout_30");
        label_7 = new QLabel(frameStopRecordingAfter);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        verticalLayout_30->addWidget(label_7);

        label_8 = new QLabel(frameStopRecordingAfter);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        verticalLayout_30->addWidget(label_8);

        label_9 = new QLabel(frameStopRecordingAfter);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        verticalLayout_30->addWidget(label_9);


        horizontalLayout_16->addLayout(verticalLayout_30);

        verticalLayout_29 = new QVBoxLayout();
        verticalLayout_29->setSpacing(6);
        verticalLayout_29->setObjectName("verticalLayout_29");

        horizontalLayout_16->addLayout(verticalLayout_29);

        horizontalLayout_16->setStretch(1, 1);

        horizontalLayout_19->addWidget(frameStopRecordingAfter);

        help_screencast_stoptimer = new QToolButton(tabTimer);
        help_screencast_stoptimer->setObjectName("help_screencast_stoptimer");
#if QT_CONFIG(tooltip)
        help_screencast_stoptimer->setToolTip(QString::fromUtf8("Help"));
#endif // QT_CONFIG(tooltip)
        help_screencast_stoptimer->setText(QString::fromUtf8("Help"));

        horizontalLayout_19->addWidget(help_screencast_stoptimer, 0, Qt::AlignTop);


        verticalLayout_23->addLayout(horizontalLayout_19);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_23->addItem(verticalSpacer_8);

        QIcon icon15;
        icon15.addFile(QString::fromUtf8(":/pictures/screencast/timer.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabTimer, icon15, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabTimer), QString::fromUtf8(""));
        tabAvailable = new QWidget();
        tabAvailable->setObjectName("tabAvailable");
        horizontalLayout_11 = new QHBoxLayout(tabAvailable);
        horizontalLayout_11->setSpacing(6);
        horizontalLayout_11->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setSpacing(0);
        verticalLayout_6->setObjectName("verticalLayout_6");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(tabAvailable);
        label_4->setObjectName("label_4");
        QFont font;
        font.setBold(true);
        label_4->setFont(font);

        gridLayout->addWidget(label_4, 0, 0, 1, 1, Qt::AlignHCenter);

        label_2 = new QLabel(tabAvailable);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        gridLayout->addWidget(label_2, 0, 1, 1, 1, Qt::AlignHCenter);

        label = new QLabel(tabAvailable);
        label->setObjectName("label");
        label->setFont(font);

        gridLayout->addWidget(label, 0, 2, 1, 1, Qt::AlignHCenter);


        verticalLayout_6->addLayout(gridLayout);

        scrollAreaAvailable = new QScrollArea(tabAvailable);
        scrollAreaAvailable->setObjectName("scrollAreaAvailable");
        scrollAreaAvailable->setMinimumSize(QSize(0, 100));
        scrollAreaAvailable->setWidgetResizable(true);
        scrollAreaWidgetContentsAvailable = new QWidget();
        scrollAreaWidgetContentsAvailable->setObjectName("scrollAreaWidgetContentsAvailable");
        scrollAreaWidgetContentsAvailable->setGeometry(QRect(0, 0, 495, 454));
        gridLayoutAvailable = new QGridLayout(scrollAreaWidgetContentsAvailable);
        gridLayoutAvailable->setSpacing(0);
        gridLayoutAvailable->setContentsMargins(11, 11, 11, 11);
        gridLayoutAvailable->setObjectName("gridLayoutAvailable");
        gridLayoutAvailable->setContentsMargins(0, -1, -1, -1);
        scrollAreaAvailable->setWidget(scrollAreaWidgetContentsAvailable);

        verticalLayout_6->addWidget(scrollAreaAvailable);


        horizontalLayout_11->addLayout(verticalLayout_6);

        verticalLayout_12 = new QVBoxLayout();
        verticalLayout_12->setSpacing(6);
        verticalLayout_12->setObjectName("verticalLayout_12");
        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setSpacing(6);
        verticalLayout_8->setObjectName("verticalLayout_8");
        label_5 = new QLabel(tabAvailable);
        label_5->setObjectName("label_5");
        label_5->setText(QString::fromUtf8(""));

        verticalLayout_8->addWidget(label_5);


        verticalLayout_12->addLayout(verticalLayout_8);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(6);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        labelAvalible = new QLabel(tabAvailable);
        labelAvalible->setObjectName("labelAvalible");
        labelAvalible->setText(QString::fromUtf8("Picture"));

        horizontalLayout_6->addWidget(labelAvalible);

        label_3 = new QLabel(tabAvailable);
        label_3->setObjectName("label_3");

        horizontalLayout_6->addWidget(label_3, 0, Qt::AlignLeft);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);


        verticalLayout_12->addLayout(horizontalLayout_6);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setSpacing(6);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        labelNotAvailable = new QLabel(tabAvailable);
        labelNotAvailable->setObjectName("labelNotAvailable");
        labelNotAvailable->setText(QString::fromUtf8("Picture"));

        horizontalLayout_9->addWidget(labelNotAvailable);

        label_6 = new QLabel(tabAvailable);
        label_6->setObjectName("label_6");

        horizontalLayout_9->addWidget(label_6);

        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_23);


        verticalLayout_12->addLayout(horizontalLayout_9);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_12->addItem(verticalSpacer_2);


        horizontalLayout_11->addLayout(verticalLayout_12);

        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setSpacing(6);
        verticalLayout_10->setObjectName("verticalLayout_10");
        help_screencast_avalaible = new QToolButton(tabAvailable);
        help_screencast_avalaible->setObjectName("help_screencast_avalaible");
        help_screencast_avalaible->setText(QString::fromUtf8("Help"));

        verticalLayout_10->addWidget(help_screencast_avalaible);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_6);


        horizontalLayout_11->addLayout(verticalLayout_10);

        horizontalLayout_11->setStretch(0, 1);
        QIcon icon16;
        icon16.addFile(QString::fromUtf8(":/pictures/screencast/supported-formats.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabAvailable, icon16, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabAvailable), QString::fromUtf8(""));
        tabAbout = new QWidget();
        tabAbout->setObjectName("tabAbout");
        verticalLayout_3 = new QVBoxLayout(tabAbout);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        gridLayout_7 = new QGridLayout();
        gridLayout_7->setSpacing(6);
        gridLayout_7->setObjectName("gridLayout_7");
        labelAutorPicture = new QLabel(tabAbout);
        labelAutorPicture->setObjectName("labelAutorPicture");
        labelAutorPicture->setMaximumSize(QSize(100, 100));
        labelAutorPicture->setText(QString::fromUtf8(""));
        labelAutorPicture->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/author.png")));
        labelAutorPicture->setScaledContents(true);
        labelAutorPicture->setAlignment(Qt::AlignCenter);

        gridLayout_7->addWidget(labelAutorPicture, 1, 1, 1, 1);

        verticalLayout_27 = new QVBoxLayout();
        verticalLayout_27->setSpacing(6);
        verticalLayout_27->setObjectName("verticalLayout_27");
        labelSourcecodeUrl = new QLabel(tabAbout);
        labelSourcecodeUrl->setObjectName("labelSourcecodeUrl");
        labelSourcecodeUrl->setText(QString::fromUtf8("Sourcecode"));
        labelSourcecodeUrl->setAlignment(Qt::AlignCenter);
        labelSourcecodeUrl->setOpenExternalLinks(true);

        verticalLayout_27->addWidget(labelSourcecodeUrl);

        labelWebSiteUrl = new QLabel(tabAbout);
        labelWebSiteUrl->setObjectName("labelWebSiteUrl");
        labelWebSiteUrl->setText(QString::fromUtf8("Website"));
        labelWebSiteUrl->setAlignment(Qt::AlignCenter);
        labelWebSiteUrl->setOpenExternalLinks(true);

        verticalLayout_27->addWidget(labelWebSiteUrl);


        gridLayout_7->addLayout(verticalLayout_27, 1, 0, 1, 1);

        verticalLayout_31 = new QVBoxLayout();
        verticalLayout_31->setSpacing(6);
        verticalLayout_31->setObjectName("verticalLayout_31");
        labelLanguageUrl = new QLabel(tabAbout);
        labelLanguageUrl->setObjectName("labelLanguageUrl");
        labelLanguageUrl->setText(QString::fromUtf8("Translation"));
        labelLanguageUrl->setAlignment(Qt::AlignCenter);
        labelLanguageUrl->setOpenExternalLinks(true);

        verticalLayout_31->addWidget(labelLanguageUrl);

        labelDonateUrl = new QLabel(tabAbout);
        labelDonateUrl->setObjectName("labelDonateUrl");
        labelDonateUrl->setText(QString::fromUtf8("Donate"));
        labelDonateUrl->setAlignment(Qt::AlignCenter);
        labelDonateUrl->setOpenExternalLinks(true);

        verticalLayout_31->addWidget(labelDonateUrl);


        gridLayout_7->addLayout(verticalLayout_31, 1, 2, 1, 1);


        verticalLayout_3->addLayout(gridLayout_7);

        verticalSpacer_11 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_11);

        line_13 = new QFrame(tabAbout);
        line_13->setObjectName("line_13");
        line_13->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_13->setFrameShadow(QFrame::Plain);
        line_13->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_3->addWidget(line_13);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_12);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(6);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_6);

        pushButtonLicense = new QPushButton(tabAbout);
        pushButtonLicense->setObjectName("pushButtonLicense");

        horizontalLayout_10->addWidget(pushButtonLicense);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_10);


        verticalLayout_3->addLayout(horizontalLayout_10);

        verticalSpacer_25 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_25);

        horizontalLayout_58 = new QHBoxLayout();
        horizontalLayout_58->setSpacing(6);
        horizontalLayout_58->setObjectName("horizontalLayout_58");
        horizontalSpacer_51 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_58->addItem(horizontalSpacer_51);

        pushButtonImages = new QPushButton(tabAbout);
        pushButtonImages->setObjectName("pushButtonImages");

        horizontalLayout_58->addWidget(pushButtonImages);

        horizontalSpacer_28 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_58->addItem(horizontalSpacer_28);


        verticalLayout_3->addLayout(horizontalLayout_58);

        label_save_image_path = new QLabel(tabAbout);
        label_save_image_path->setObjectName("label_save_image_path");
        label_save_image_path->setText(QString::fromUtf8(""));

        verticalLayout_3->addWidget(label_save_image_path);

        line_cisco = new QFrame(tabAbout);
        line_cisco->setObjectName("line_cisco");
        line_cisco->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_cisco->setFrameShadow(QFrame::Plain);
        line_cisco->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_3->addWidget(line_cisco);

        frame_cisco = new QFrame(tabAbout);
        frame_cisco->setObjectName("frame_cisco");
        frame_cisco->setFrameShape(QFrame::StyledPanel);
        frame_cisco->setFrameShadow(QFrame::Raised);
        verticalLayout_13 = new QVBoxLayout(frame_cisco);
        verticalLayout_13->setSpacing(6);
        verticalLayout_13->setContentsMargins(11, 11, 11, 11);
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalLayout_13->setContentsMargins(-1, 0, -1, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName("gridLayout_2");
        frame = new QFrame(frame_cisco);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Sunken);
        verticalLayout_20 = new QVBoxLayout(frame);
        verticalLayout_20->setSpacing(6);
        verticalLayout_20->setContentsMargins(11, 11, 11, 11);
        verticalLayout_20->setObjectName("verticalLayout_20");
        label_cisco_hint = new QLabel(frame);
        label_cisco_hint->setObjectName("label_cisco_hint");
        label_cisco_hint->setFont(font);
        label_cisco_hint->setText(QString::fromUtf8("OpenH264 Video Codec provided by Cisco Systems, Inc."));

        verticalLayout_20->addWidget(label_cisco_hint, 0, Qt::AlignHCenter);

        pushButtonCiscoLicense = new QPushButton(frame);
        pushButtonCiscoLicense->setObjectName("pushButtonCiscoLicense");

        verticalLayout_20->addWidget(pushButtonCiscoLicense, 0, Qt::AlignHCenter);

        label_openh264_homepage = new QLabel(frame);
        label_openh264_homepage->setObjectName("label_openh264_homepage");
        label_openh264_homepage->setText(QString::fromUtf8("<html><head/><body><p><a href=\"https://www.openh264.org\"><span style=\" text-decoration: underline; color:#2980b9;\">https://www.openh264.org</span></a></p></body></html>"));
        label_openh264_homepage->setOpenExternalLinks(true);

        verticalLayout_20->addWidget(label_openh264_homepage, 0, Qt::AlignHCenter);

        horizontalLayout_35 = new QHBoxLayout();
        horizontalLayout_35->setSpacing(6);
        horizontalLayout_35->setObjectName("horizontalLayout_35");
        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_35->addItem(horizontalSpacer_21);

        radioButton_cisco_on = new QRadioButton(frame);
        radioButton_cisco_on->setObjectName("radioButton_cisco_on");

        horizontalLayout_35->addWidget(radioButton_cisco_on);

        radioButton_cisco_off = new QRadioButton(frame);
        radioButton_cisco_off->setObjectName("radioButton_cisco_off");

        horizontalLayout_35->addWidget(radioButton_cisco_off);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_35->addItem(horizontalSpacer_20);


        verticalLayout_20->addLayout(horizontalLayout_35);


        gridLayout_2->addWidget(frame, 1, 0, 1, 2);


        verticalLayout_13->addLayout(gridLayout_2);


        verticalLayout_3->addWidget(frame_cisco);

        QIcon icon17;
        icon17.addFile(QString::fromUtf8(":/pictures/screencast/help-about.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabAbout, icon17, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabAbout), QString::fromUtf8(""));

        verticalLayout->addWidget(tabWidgetScreencast);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        pushButtonStart = new QPushButton(tabSidebarScreencast);
        pushButtonStart->setObjectName("pushButtonStart");
        pushButtonStart->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonStart->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        pushButtonStart->setStyleSheet(QString::fromUtf8(""));

        horizontalLayout->addWidget(pushButtonStart);

        pushButtonStop = new QPushButton(tabSidebarScreencast);
        pushButtonStop->setObjectName("pushButtonStop");
        pushButtonStop->setEnabled(false);
        pushButtonStop->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonStop->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)

        horizontalLayout->addWidget(pushButtonStop);

        pushButtonPause = new QPushButton(tabSidebarScreencast);
        pushButtonPause->setObjectName("pushButtonPause");
        pushButtonPause->setEnabled(false);
        pushButtonPause->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonPause->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)

        horizontalLayout->addWidget(pushButtonPause);

        pushButtonContinue = new QPushButton(tabSidebarScreencast);
        pushButtonContinue->setObjectName("pushButtonContinue");
        pushButtonContinue->setEnabled(false);
        pushButtonContinue->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonContinue->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)

        horizontalLayout->addWidget(pushButtonContinue);

        pushButtonPlay = new QPushButton(tabSidebarScreencast);
        pushButtonPlay->setObjectName("pushButtonPlay");
        pushButtonPlay->setFont(font);

        horizontalLayout->addWidget(pushButtonPlay);

        pushButtonScreencastOpenfolder = new QPushButton(tabSidebarScreencast);
        pushButtonScreencastOpenfolder->setObjectName("pushButtonScreencastOpenfolder");
        pushButtonScreencastOpenfolder->setFont(font);

        horizontalLayout->addWidget(pushButtonScreencastOpenfolder);

        pushButtonScreencastSnapshot = new QPushButton(tabSidebarScreencast);
        pushButtonScreencastSnapshot->setObjectName("pushButtonScreencastSnapshot");
        pushButtonScreencastSnapshot->setFont(font);

        horizontalLayout->addWidget(pushButtonScreencastSnapshot);

        help_screencast_execute = new QToolButton(tabSidebarScreencast);
        help_screencast_execute->setObjectName("help_screencast_execute");
        help_screencast_execute->setText(QString::fromUtf8("Help"));

        horizontalLayout->addWidget(help_screencast_execute);


        verticalLayout->addLayout(horizontalLayout);

        QIcon icon18;
        icon18.addFile(QString::fromUtf8(":/pictures/screencast/monitor-sidebar.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetSideBar->addTab(tabSidebarScreencast, icon18, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarScreencast), QString::fromUtf8(""));
        tabSidebarCamera = new QWidget();
        tabSidebarCamera->setObjectName("tabSidebarCamera");
        verticalLayout_17 = new QVBoxLayout(tabSidebarCamera);
        verticalLayout_17->setSpacing(0);
        verticalLayout_17->setContentsMargins(11, 11, 11, 11);
        verticalLayout_17->setObjectName("verticalLayout_17");
        verticalLayout_17->setContentsMargins(0, 0, 0, 0);
        tabWidgetCamera = new QTabWidget(tabSidebarCamera);
        tabWidgetCamera->setObjectName("tabWidgetCamera");
#if QT_CONFIG(tooltip)
        tabWidgetCamera->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        tabWidgetCamera->setIconSize(QSize(48, 48));
        tabCamera = new QWidget();
        tabCamera->setObjectName("tabCamera");
#if QT_CONFIG(tooltip)
        tabCamera->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        verticalLayout_16 = new QVBoxLayout(tabCamera);
        verticalLayout_16->setSpacing(6);
        verticalLayout_16->setContentsMargins(11, 11, 11, 11);
        verticalLayout_16->setObjectName("verticalLayout_16");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setSpacing(6);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setVerticalSpacing(9);
        gridLayout_4->setContentsMargins(0, -1, -1, 0);
        help_camera_camera = new QToolButton(tabCamera);
        help_camera_camera->setObjectName("help_camera_camera");
        help_camera_camera->setText(QString::fromUtf8("Help"));

        gridLayout_4->addWidget(help_camera_camera, 0, 3, 1, 1, Qt::AlignTop);

        label_camera_window_zoom = new QLabel(tabCamera);
        label_camera_window_zoom->setObjectName("label_camera_window_zoom");
        label_camera_window_zoom->setMinimumSize(QSize(34, 34));
        label_camera_window_zoom->setMaximumSize(QSize(34, 34));
        label_camera_window_zoom->setText(QString::fromUtf8(""));
        label_camera_window_zoom->setPixmap(QPixmap(QString::fromUtf8(":/pictures/systray/magnification.png")));
        label_camera_window_zoom->setScaledContents(true);

        gridLayout_4->addWidget(label_camera_window_zoom, 2, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setSpacing(6);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalLayout_14->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraInvert = new QCheckBox(tabCamera);
        checkBoxCameraInvert->setObjectName("checkBoxCameraInvert");
        checkBoxCameraInvert->setEnabled(false);

        horizontalLayout_14->addWidget(checkBoxCameraInvert);

        horizontalSpacer_39 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_39);

        checkBoxCameraGray = new QCheckBox(tabCamera);
        checkBoxCameraGray->setObjectName("checkBoxCameraGray");
        checkBoxCameraGray->setEnabled(false);

        horizontalLayout_14->addWidget(checkBoxCameraGray);

        horizontalSpacer_40 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_40);

        checkBoxCameraMono = new QCheckBox(tabCamera);
        checkBoxCameraMono->setObjectName("checkBoxCameraMono");
        checkBoxCameraMono->setEnabled(false);

        horizontalLayout_14->addWidget(checkBoxCameraMono);

        horizontalSpacer_33 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_33);


        gridLayout_4->addLayout(horizontalLayout_14, 6, 0, 1, 3);

        horizontalLayout_zoom = new QHBoxLayout();
        horizontalLayout_zoom->setSpacing(12);
        horizontalLayout_zoom->setObjectName("horizontalLayout_zoom");
        horizontalLayout_zoom->setContentsMargins(0, -1, -1, -1);

        gridLayout_4->addLayout(horizontalLayout_zoom, 2, 1, 1, 2);

        horizontalLayout_63 = new QHBoxLayout();
        horizontalLayout_63->setSpacing(6);
        horizontalLayout_63->setObjectName("horizontalLayout_63");
        horizontalLayout_63->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraOnOff = new QCheckBox(tabCamera);
        checkBoxCameraOnOff->setObjectName("checkBoxCameraOnOff");
        checkBoxCameraOnOff->setEnabled(false);
#if QT_CONFIG(tooltip)
        checkBoxCameraOnOff->setToolTip(QString::fromUtf8("CTRL+SHIFT+F8"));
#endif // QT_CONFIG(tooltip)

        horizontalLayout_63->addWidget(checkBoxCameraOnOff);

        comboBoxCamera = new QComboBox(tabCamera);
        comboBoxCamera->setObjectName("comboBoxCamera");
        comboBoxCamera->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(comboBoxCamera->sizePolicy().hasHeightForWidth());
        comboBoxCamera->setSizePolicy(sizePolicy3);
        comboBoxCamera->setCurrentText(QString::fromUtf8(""));
        comboBoxCamera->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_63->addWidget(comboBoxCamera);

        comboBoxCameraResolution = new QComboBox(tabCamera);
        comboBoxCameraResolution->setObjectName("comboBoxCameraResolution");
        comboBoxCameraResolution->setEnabled(false);
        comboBoxCameraResolution->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_63->addWidget(comboBoxCameraResolution);


        gridLayout_4->addLayout(horizontalLayout_63, 0, 0, 1, 3);

        horizontalLayout_66 = new QHBoxLayout();
        horizontalLayout_66->setSpacing(6);
        horizontalLayout_66->setObjectName("horizontalLayout_66");
        horizontalLayout_66->setContentsMargins(0, -1, -1, -1);
        horizontalLayout_45 = new QHBoxLayout();
        horizontalLayout_45->setSpacing(12);
        horizontalLayout_45->setObjectName("horizontalLayout_45");

        horizontalLayout_66->addLayout(horizontalLayout_45);

        labelCameraWindowSize = new QLabel(tabCamera);
        labelCameraWindowSize->setObjectName("labelCameraWindowSize");
        labelCameraWindowSize->setEnabled(true);
        labelCameraWindowSize->setText(QString::fromUtf8("---x---"));
        labelCameraWindowSize->setAlignment(Qt::AlignCenter);

        horizontalLayout_66->addWidget(labelCameraWindowSize);


        gridLayout_4->addLayout(horizontalLayout_66, 1, 1, 1, 2);

        label_camera_window_resize = new QLabel(tabCamera);
        label_camera_window_resize->setObjectName("label_camera_window_resize");
        label_camera_window_resize->setEnabled(true);
        label_camera_window_resize->setMaximumSize(QSize(34, 34));
        label_camera_window_resize->setText(QString::fromUtf8(""));
        label_camera_window_resize->setPixmap(QPixmap(QString::fromUtf8(":/pictures/camera/window-resize.png")));
        label_camera_window_resize->setScaledContents(true);

        gridLayout_4->addWidget(label_camera_window_resize, 1, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(6);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraMirrorVertical = new QCheckBox(tabCamera);
        checkBoxCameraMirrorVertical->setObjectName("checkBoxCameraMirrorVertical");
        checkBoxCameraMirrorVertical->setEnabled(false);

        horizontalLayout_12->addWidget(checkBoxCameraMirrorVertical);

        horizontalSpacer_38 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_38);

        checkBoxCameraMirrorHorizontal = new QCheckBox(tabCamera);
        checkBoxCameraMirrorHorizontal->setObjectName("checkBoxCameraMirrorHorizontal");
        checkBoxCameraMirrorHorizontal->setEnabled(false);

        horizontalLayout_12->addWidget(checkBoxCameraMirrorHorizontal);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_7);


        gridLayout_4->addLayout(horizontalLayout_12, 5, 0, 1, 3);

        horizontalLayout_65 = new QHBoxLayout();
        horizontalLayout_65->setSpacing(0);
        horizontalLayout_65->setObjectName("horizontalLayout_65");
        horizontalLayout_65->setContentsMargins(0, -1, -1, -1);
        horizontalSpacer_41 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_41);

        toolButton_camera_view_rectangle = new QToolButton(tabCamera);
        toolButton_camera_view_rectangle->setObjectName("toolButton_camera_view_rectangle");
        toolButton_camera_view_rectangle->setText(QString::fromUtf8(""));
        QIcon icon19;
        icon19.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon19.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_rectangle->setIcon(icon19);
        toolButton_camera_view_rectangle->setIconSize(QSize(34, 34));
        toolButton_camera_view_rectangle->setCheckable(true);
        toolButton_camera_view_rectangle->setChecked(true);
        toolButton_camera_view_rectangle->setAutoExclusive(true);
        toolButton_camera_view_rectangle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_rectangle);

        horizontalSpacer_35 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_35);

        toolButton_camera_view_ellipse = new QToolButton(tabCamera);
        toolButton_camera_view_ellipse->setObjectName("toolButton_camera_view_ellipse");
        toolButton_camera_view_ellipse->setText(QString::fromUtf8(""));
        QIcon icon20;
        icon20.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon20.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_ellipse->setIcon(icon20);
        toolButton_camera_view_ellipse->setIconSize(QSize(34, 34));
        toolButton_camera_view_ellipse->setCheckable(true);
        toolButton_camera_view_ellipse->setAutoExclusive(true);
        toolButton_camera_view_ellipse->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_ellipse);

        horizontalSpacer_36 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_36);

        toolButton_camera_view_circle = new QToolButton(tabCamera);
        toolButton_camera_view_circle->setObjectName("toolButton_camera_view_circle");
        toolButton_camera_view_circle->setText(QString::fromUtf8(""));
        QIcon icon21;
        icon21.addFile(QString::fromUtf8(":/pictures/camera/window-circle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon21.addFile(QString::fromUtf8(":/pictures/camera/window-circle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_circle->setIcon(icon21);
        toolButton_camera_view_circle->setIconSize(QSize(34, 34));
        toolButton_camera_view_circle->setCheckable(true);
        toolButton_camera_view_circle->setAutoExclusive(true);
        toolButton_camera_view_circle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_circle);

        horizontalSpacer_37 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_37);


        gridLayout_4->addLayout(horizontalLayout_65, 3, 0, 1, 3);

        horizontalLayout_42 = new QHBoxLayout();
        horizontalLayout_42->setSpacing(6);
        horizontalLayout_42->setObjectName("horizontalLayout_42");
        horizontalLayout_42->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraWindowFrame = new QCheckBox(tabCamera);
        checkBoxCameraWindowFrame->setObjectName("checkBoxCameraWindowFrame");
        checkBoxCameraWindowFrame->setEnabled(false);

        horizontalLayout_42->addWidget(checkBoxCameraWindowFrame);


        gridLayout_4->addLayout(horizontalLayout_42, 4, 0, 1, 3);


        verticalLayout_16->addLayout(gridLayout_4);

        verticalSpacer_26 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_16->addItem(verticalSpacer_26);

        tabWidgetCamera->addTab(tabCamera, icon1, QString());
        tabWidgetCamera->setTabText(tabWidgetCamera->indexOf(tabCamera), QString::fromUtf8(""));

        verticalLayout_17->addWidget(tabWidgetCamera);

        QIcon icon22;
        icon22.addFile(QString::fromUtf8(":/pictures/camera/camera-sidebar.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetSideBar->addTab(tabSidebarCamera, icon22, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarCamera), QString::fromUtf8(""));
        tabSidebarShowClick = new QWidget();
        tabSidebarShowClick->setObjectName("tabSidebarShowClick");
        horizontalLayout_40 = new QHBoxLayout(tabSidebarShowClick);
        horizontalLayout_40->setSpacing(0);
        horizontalLayout_40->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_40->setObjectName("horizontalLayout_40");
        horizontalLayout_40->setContentsMargins(0, 0, 0, 0);
        tabWidgetShowClick = new QTabWidget(tabSidebarShowClick);
        tabWidgetShowClick->setObjectName("tabWidgetShowClick");
        tabWidgetShowClick->setIconSize(QSize(48, 48));
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_35 = new QVBoxLayout(tab);
        verticalLayout_35->setSpacing(6);
        verticalLayout_35->setContentsMargins(11, 11, 11, 11);
        verticalLayout_35->setObjectName("verticalLayout_35");
        gridLayoutShowClick = new QGridLayout();
        gridLayoutShowClick->setSpacing(6);
        gridLayoutShowClick->setObjectName("gridLayoutShowClick");
        line_4 = new QFrame(tab);
        line_4->setObjectName("line_4");
        line_4->setMinimumSize(QSize(20, 0));
        line_4->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_4->setFrameShadow(QFrame::Plain);
        line_4->setFrameShape(QFrame::Shape::VLine);

        gridLayoutShowClick->addWidget(line_4, 0, 4, 11, 1);

        horizontalLayout_41 = new QHBoxLayout();
        horizontalLayout_41->setSpacing(6);
        horizontalLayout_41->setObjectName("horizontalLayout_41");
        label_30 = new QLabel(tab);
        label_30->setObjectName("label_30");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_30->sizePolicy().hasHeightForWidth());
        label_30->setSizePolicy(sizePolicy4);
        label_30->setMaximumSize(QSize(34, 13));
        label_30->setText(QString::fromUtf8(""));
        label_30->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/cursor.png")));
        label_30->setScaledContents(true);

        horizontalLayout_41->addWidget(label_30, 0, Qt::AlignLeft);

        horizontalLayoutDiameter = new QHBoxLayout();
        horizontalLayoutDiameter->setSpacing(6);
        horizontalLayoutDiameter->setObjectName("horizontalLayoutDiameter");

        horizontalLayout_41->addLayout(horizontalLayoutDiameter);


        gridLayoutShowClick->addLayout(horizontalLayout_41, 6, 5, 1, 3);

        toolButtonHaloOpacityDefault = new QToolButton(tab);
        toolButtonHaloOpacityDefault->setObjectName("toolButtonHaloOpacityDefault");
        toolButtonHaloOpacityDefault->setText(QString::fromUtf8(""));
        toolButtonHaloOpacityDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonHaloOpacityDefault, 8, 8, 1, 1);

        toolButtonHaloDiameterDefault = new QToolButton(tab);
        toolButtonHaloDiameterDefault->setObjectName("toolButtonHaloDiameterDefault");
        toolButtonHaloDiameterDefault->setText(QString::fromUtf8(""));
        toolButtonHaloDiameterDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonHaloDiameterDefault, 6, 8, 1, 1);

        gridLayout_showclick_color_pushButton = new QGridLayout();
        gridLayout_showclick_color_pushButton->setSpacing(6);
        gridLayout_showclick_color_pushButton->setObjectName("gridLayout_showclick_color_pushButton");
        horizontalLayout_showclick_darkRed = new QHBoxLayout();
        horizontalLayout_showclick_darkRed->setSpacing(6);
        horizontalLayout_showclick_darkRed->setObjectName("horizontalLayout_showclick_darkRed");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkRed, 0, 3, 1, 1);

        horizontalLayout_showclick_darkGreen = new QHBoxLayout();
        horizontalLayout_showclick_darkGreen->setSpacing(6);
        horizontalLayout_showclick_darkGreen->setObjectName("horizontalLayout_showclick_darkGreen");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkGreen, 1, 1, 1, 1);

        horizontalLayout_showclick_white = new QHBoxLayout();
        horizontalLayout_showclick_white->setSpacing(6);
        horizontalLayout_showclick_white->setObjectName("horizontalLayout_showclick_white");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_white, 0, 0, 1, 1);

        horizontalLayout_showclick_green = new QHBoxLayout();
        horizontalLayout_showclick_green->setSpacing(6);
        horizontalLayout_showclick_green->setObjectName("horizontalLayout_showclick_green");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_green, 1, 0, 1, 1);

        toolButtonShowclickColorDefault = new QToolButton(tab);
        toolButtonShowclickColorDefault->setObjectName("toolButtonShowclickColorDefault");
        toolButtonShowclickColorDefault->setText(QString::fromUtf8(""));
        toolButtonShowclickColorDefault->setIcon(icon7);

        gridLayout_showclick_color_pushButton->addWidget(toolButtonShowclickColorDefault, 0, 4, 4, 1, Qt::AlignVCenter);

        horizontalLayout_showclick_red = new QHBoxLayout();
        horizontalLayout_showclick_red->setSpacing(6);
        horizontalLayout_showclick_red->setObjectName("horizontalLayout_showclick_red");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_red, 0, 2, 1, 1);

        horizontalLayout_showclick_yellow = new QHBoxLayout();
        horizontalLayout_showclick_yellow->setSpacing(6);
        horizontalLayout_showclick_yellow->setObjectName("horizontalLayout_showclick_yellow");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_yellow, 3, 0, 1, 1);

        horizontalLayout_showclick_darkYellow = new QHBoxLayout();
        horizontalLayout_showclick_darkYellow->setSpacing(6);
        horizontalLayout_showclick_darkYellow->setObjectName("horizontalLayout_showclick_darkYellow");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkYellow, 3, 1, 1, 1);

        horizontalLayout_showclick_darkMagenta = new QHBoxLayout();
        horizontalLayout_showclick_darkMagenta->setSpacing(6);
        horizontalLayout_showclick_darkMagenta->setObjectName("horizontalLayout_showclick_darkMagenta");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkMagenta, 2, 3, 1, 1);

        horizontalLayout_showclick_blue = new QHBoxLayout();
        horizontalLayout_showclick_blue->setSpacing(6);
        horizontalLayout_showclick_blue->setObjectName("horizontalLayout_showclick_blue");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_blue, 1, 2, 1, 1);

        horizontalLayout_showclick_magenta = new QHBoxLayout();
        horizontalLayout_showclick_magenta->setSpacing(6);
        horizontalLayout_showclick_magenta->setObjectName("horizontalLayout_showclick_magenta");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_magenta, 2, 2, 1, 1);

        horizontalLayout_showclick_gray = new QHBoxLayout();
        horizontalLayout_showclick_gray->setSpacing(6);
        horizontalLayout_showclick_gray->setObjectName("horizontalLayout_showclick_gray");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_gray, 3, 2, 1, 1);

        horizontalLayout_showclick_cyan = new QHBoxLayout();
        horizontalLayout_showclick_cyan->setSpacing(6);
        horizontalLayout_showclick_cyan->setObjectName("horizontalLayout_showclick_cyan");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_cyan, 2, 0, 1, 1);

        horizontalLayout_showclick_darkBlue = new QHBoxLayout();
        horizontalLayout_showclick_darkBlue->setSpacing(6);
        horizontalLayout_showclick_darkBlue->setObjectName("horizontalLayout_showclick_darkBlue");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkBlue, 1, 3, 1, 1);

        horizontalLayout_showclick_darkGray = new QHBoxLayout();
        horizontalLayout_showclick_darkGray->setSpacing(6);
        horizontalLayout_showclick_darkGray->setObjectName("horizontalLayout_showclick_darkGray");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkGray, 3, 3, 1, 1);

        horizontalLayout_showclick_black = new QHBoxLayout();
        horizontalLayout_showclick_black->setSpacing(6);
        horizontalLayout_showclick_black->setObjectName("horizontalLayout_showclick_black");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_black, 0, 1, 1, 1);

        horizontalLayout_showclick_darkCyan = new QHBoxLayout();
        horizontalLayout_showclick_darkCyan->setSpacing(6);
        horizontalLayout_showclick_darkCyan->setObjectName("horizontalLayout_showclick_darkCyan");

        gridLayout_showclick_color_pushButton->addLayout(horizontalLayout_showclick_darkCyan, 2, 1, 1, 1);


        gridLayoutShowClick->addLayout(gridLayout_showclick_color_pushButton, 2, 0, 3, 4);

        horizontalLayout_43 = new QHBoxLayout();
        horizontalLayout_43->setSpacing(6);
        horizontalLayout_43->setObjectName("horizontalLayout_43");
        label_31 = new QLabel(tab);
        label_31->setObjectName("label_31");
        sizePolicy4.setHeightForWidth(label_31->sizePolicy().hasHeightForWidth());
        label_31->setSizePolicy(sizePolicy4);
        label_31->setMaximumSize(QSize(34, 13));
        label_31->setText(QString::fromUtf8(""));
        label_31->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/transparenz.png")));
        label_31->setScaledContents(true);

        horizontalLayout_43->addWidget(label_31, 0, Qt::AlignLeft);

        horizontalLayoutHaloOpacity = new QHBoxLayout();
        horizontalLayoutHaloOpacity->setSpacing(6);
        horizontalLayoutHaloOpacity->setObjectName("horizontalLayoutHaloOpacity");

        horizontalLayout_43->addLayout(horizontalLayoutHaloOpacity);


        gridLayoutShowClick->addLayout(horizontalLayout_43, 8, 5, 1, 3);

        horizontalLayout_32 = new QHBoxLayout();
        horizontalLayout_32->setSpacing(6);
        horizontalLayout_32->setObjectName("horizontalLayout_32");
        label_27 = new QLabel(tab);
        label_27->setObjectName("label_27");
        sizePolicy4.setHeightForWidth(label_27->sizePolicy().hasHeightForWidth());
        label_27->setSizePolicy(sizePolicy4);
        label_27->setMaximumSize(QSize(34, 13));
        label_27->setText(QString::fromUtf8(""));
        label_27->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/transparenz.png")));
        label_27->setScaledContents(true);

        horizontalLayout_32->addWidget(label_27, 0, Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayoutOpacity = new QHBoxLayout();
        horizontalLayoutOpacity->setSpacing(6);
        horizontalLayoutOpacity->setObjectName("horizontalLayoutOpacity");

        horizontalLayout_32->addLayout(horizontalLayoutOpacity);


        gridLayoutShowClick->addLayout(horizontalLayout_32, 8, 0, 1, 3);

        toolButtonShowclickDiameterDefault = new QToolButton(tab);
        toolButtonShowclickDiameterDefault->setObjectName("toolButtonShowclickDiameterDefault");
        toolButtonShowclickDiameterDefault->setText(QString::fromUtf8(""));
        toolButtonShowclickDiameterDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonShowclickDiameterDefault, 6, 3, 1, 1);

        frame_3 = new QFrame(tab);
        frame_3->setObjectName("frame_3");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(frame_3->sizePolicy().hasHeightForWidth());
        frame_3->setSizePolicy(sizePolicy5);
        frame_3->setMinimumSize(QSize(0, 100));
        frame_3->setFrameShape(QFrame::NoFrame);
        horizontalLayout_38 = new QHBoxLayout(frame_3);
        horizontalLayout_38->setSpacing(0);
        horizontalLayout_38->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_38->setObjectName("horizontalLayout_38");
        horizontalLayout_38->setContentsMargins(1, 0, 0, 0);

        gridLayoutShowClick->addWidget(frame_3, 5, 0, 1, 4);

        toolButtonShowclickOpacityDefault = new QToolButton(tab);
        toolButtonShowclickOpacityDefault->setObjectName("toolButtonShowclickOpacityDefault");
        toolButtonShowclickOpacityDefault->setText(QString::fromUtf8(""));
        toolButtonShowclickOpacityDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonShowclickOpacityDefault, 8, 3, 1, 1);

        gridLayout_halo_color_pushButton = new QGridLayout();
        gridLayout_halo_color_pushButton->setSpacing(6);
        gridLayout_halo_color_pushButton->setObjectName("gridLayout_halo_color_pushButton");
        horizontalLayout_halo_darkGray = new QHBoxLayout();
        horizontalLayout_halo_darkGray->setSpacing(6);
        horizontalLayout_halo_darkGray->setObjectName("horizontalLayout_halo_darkGray");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkGray, 3, 3, 1, 1);

        horizontalLayout_halo_green = new QHBoxLayout();
        horizontalLayout_halo_green->setSpacing(6);
        horizontalLayout_halo_green->setObjectName("horizontalLayout_halo_green");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_green, 1, 0, 1, 1);

        horizontalLayout_halo_red = new QHBoxLayout();
        horizontalLayout_halo_red->setSpacing(6);
        horizontalLayout_halo_red->setObjectName("horizontalLayout_halo_red");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_red, 0, 2, 1, 1);

        horizontalLayout_halo_cyan = new QHBoxLayout();
        horizontalLayout_halo_cyan->setSpacing(6);
        horizontalLayout_halo_cyan->setObjectName("horizontalLayout_halo_cyan");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_cyan, 2, 0, 1, 1);

        horizontalLayout_halo_white = new QHBoxLayout();
        horizontalLayout_halo_white->setSpacing(6);
        horizontalLayout_halo_white->setObjectName("horizontalLayout_halo_white");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_white, 0, 0, 1, 1);

        horizontalLayout_halo_magenta = new QHBoxLayout();
        horizontalLayout_halo_magenta->setSpacing(6);
        horizontalLayout_halo_magenta->setObjectName("horizontalLayout_halo_magenta");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_magenta, 2, 2, 1, 1);

        horizontalLayout_halo_darkMagenta = new QHBoxLayout();
        horizontalLayout_halo_darkMagenta->setSpacing(6);
        horizontalLayout_halo_darkMagenta->setObjectName("horizontalLayout_halo_darkMagenta");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkMagenta, 2, 3, 1, 1);

        horizontalLayout_halo_darkGreen = new QHBoxLayout();
        horizontalLayout_halo_darkGreen->setSpacing(6);
        horizontalLayout_halo_darkGreen->setObjectName("horizontalLayout_halo_darkGreen");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkGreen, 1, 1, 1, 1);

        horizontalLayout_halo_black = new QHBoxLayout();
        horizontalLayout_halo_black->setSpacing(6);
        horizontalLayout_halo_black->setObjectName("horizontalLayout_halo_black");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_black, 0, 1, 1, 1);

        horizontalLayout_halo_darkCyan = new QHBoxLayout();
        horizontalLayout_halo_darkCyan->setSpacing(6);
        horizontalLayout_halo_darkCyan->setObjectName("horizontalLayout_halo_darkCyan");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkCyan, 2, 1, 1, 1);

        horizontalLayout_halo_darkYellow = new QHBoxLayout();
        horizontalLayout_halo_darkYellow->setSpacing(6);
        horizontalLayout_halo_darkYellow->setObjectName("horizontalLayout_halo_darkYellow");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkYellow, 3, 1, 1, 1);

        horizontalLayout_halo_blue = new QHBoxLayout();
        horizontalLayout_halo_blue->setSpacing(6);
        horizontalLayout_halo_blue->setObjectName("horizontalLayout_halo_blue");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_blue, 1, 2, 1, 1);

        horizontalLayout_halo_darkBlue = new QHBoxLayout();
        horizontalLayout_halo_darkBlue->setSpacing(6);
        horizontalLayout_halo_darkBlue->setObjectName("horizontalLayout_halo_darkBlue");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkBlue, 1, 3, 1, 1);

        horizontalLayout_halo_gray = new QHBoxLayout();
        horizontalLayout_halo_gray->setSpacing(6);
        horizontalLayout_halo_gray->setObjectName("horizontalLayout_halo_gray");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_gray, 3, 2, 1, 1);

        horizontalLayout_halo_darkRed = new QHBoxLayout();
        horizontalLayout_halo_darkRed->setSpacing(6);
        horizontalLayout_halo_darkRed->setObjectName("horizontalLayout_halo_darkRed");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_darkRed, 0, 3, 1, 1);

        horizontalLayout_halo_yellow = new QHBoxLayout();
        horizontalLayout_halo_yellow->setSpacing(6);
        horizontalLayout_halo_yellow->setObjectName("horizontalLayout_halo_yellow");

        gridLayout_halo_color_pushButton->addLayout(horizontalLayout_halo_yellow, 3, 0, 1, 1);

        toolButtonHaloColorDefault = new QToolButton(tab);
        toolButtonHaloColorDefault->setObjectName("toolButtonHaloColorDefault");
        toolButtonHaloColorDefault->setText(QString::fromUtf8(""));
        toolButtonHaloColorDefault->setIcon(icon7);

        gridLayout_halo_color_pushButton->addWidget(toolButtonHaloColorDefault, 0, 4, 4, 1, Qt::AlignVCenter);


        gridLayoutShowClick->addLayout(gridLayout_halo_color_pushButton, 2, 5, 3, 4);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setSpacing(6);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_11);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_5);


        gridLayoutShowClick->addLayout(horizontalLayout_15, 10, 0, 1, 3);

        toolButtonHaloHoleDefault = new QToolButton(tab);
        toolButtonHaloHoleDefault->setObjectName("toolButtonHaloHoleDefault");
        toolButtonHaloHoleDefault->setText(QString::fromUtf8(""));
        toolButtonHaloHoleDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonHaloHoleDefault, 7, 8, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(6);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_26 = new QLabel(tab);
        label_26->setObjectName("label_26");
        sizePolicy4.setHeightForWidth(label_26->sizePolicy().hasHeightForWidth());
        label_26->setSizePolicy(sizePolicy4);
        label_26->setMinimumSize(QSize(34, 0));
        label_26->setMaximumSize(QSize(34, 34));
        label_26->setText(QString::fromUtf8(""));
        label_26->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/sandglass.png")));
        label_26->setScaledContents(true);

        horizontalLayout_5->addWidget(label_26, 0, Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayoutShowtime = new QHBoxLayout();
        horizontalLayoutShowtime->setSpacing(6);
        horizontalLayoutShowtime->setObjectName("horizontalLayoutShowtime");

        horizontalLayout_5->addLayout(horizontalLayoutShowtime);


        gridLayoutShowClick->addLayout(horizontalLayout_5, 7, 0, 1, 3);

        horizontalLayout_47 = new QHBoxLayout();
        horizontalLayout_47->setSpacing(6);
        horizontalLayout_47->setObjectName("horizontalLayout_47");
        label_32 = new QLabel(tab);
        label_32->setObjectName("label_32");
        label_32->setMaximumSize(QSize(34, 13));
        label_32->setText(QString::fromUtf8(""));
        label_32->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/halo.png")));
        label_32->setScaledContents(true);

        horizontalLayout_47->addWidget(label_32, 0, Qt::AlignLeft);

        horizontalLayoutHaloHole = new QHBoxLayout();
        horizontalLayoutHaloHole->setSpacing(6);
        horizontalLayoutHaloHole->setObjectName("horizontalLayoutHaloHole");

        horizontalLayout_47->addLayout(horizontalLayoutHaloHole);


        gridLayoutShowClick->addLayout(horizontalLayout_47, 7, 5, 1, 3);

        horizontalLayout_48 = new QHBoxLayout();
        horizontalLayout_48->setSpacing(6);
        horizontalLayout_48->setObjectName("horizontalLayout_48");
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_48->addItem(horizontalSpacer_15);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_48->addItem(horizontalSpacer_13);


        gridLayoutShowClick->addLayout(horizontalLayout_48, 10, 5, 1, 3);

        label_33 = new QLabel(tab);
        label_33->setObjectName("label_33");
        QFont font1;
        font1.setPointSize(14);
        label_33->setFont(font1);
        label_33->setText(QString::fromUtf8("Showclick"));

        gridLayoutShowClick->addWidget(label_33, 0, 0, 1, 4, Qt::AlignHCenter);

        label_34 = new QLabel(tab);
        label_34->setObjectName("label_34");
        label_34->setFont(font1);
        label_34->setText(QString::fromUtf8("Halo"));

        gridLayoutShowClick->addWidget(label_34, 0, 5, 1, 4, Qt::AlignHCenter);

        verticalSpacer_27 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayoutShowClick->addItem(verticalSpacer_27, 9, 1, 1, 1);

        frame_2 = new QFrame(tab);
        frame_2->setObjectName("frame_2");
        sizePolicy5.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy5);
        frame_2->setMinimumSize(QSize(0, 100));
        horizontalLayout_61 = new QHBoxLayout(frame_2);
        horizontalLayout_61->setSpacing(0);
        horizontalLayout_61->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_61->setObjectName("horizontalLayout_61");
        horizontalLayout_61->setContentsMargins(1, 0, 0, 0);

        gridLayoutShowClick->addWidget(frame_2, 5, 5, 1, 4);

        horizontalLayout_39 = new QHBoxLayout();
        horizontalLayout_39->setSpacing(6);
        horizontalLayout_39->setObjectName("horizontalLayout_39");
        label_28 = new QLabel(tab);
        label_28->setObjectName("label_28");
        sizePolicy4.setHeightForWidth(label_28->sizePolicy().hasHeightForWidth());
        label_28->setSizePolicy(sizePolicy4);
        label_28->setMaximumSize(QSize(34, 13));
        label_28->setText(QString::fromUtf8(""));
        label_28->setPixmap(QPixmap(QString::fromUtf8(":/pictures/showClick/cursor.png")));
        label_28->setScaledContents(true);
        label_28->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_39->addWidget(label_28, 0, Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayoutCircle = new QHBoxLayout();
        horizontalLayoutCircle->setSpacing(6);
        horizontalLayoutCircle->setObjectName("horizontalLayoutCircle");

        horizontalLayout_39->addLayout(horizontalLayoutCircle);


        gridLayoutShowClick->addLayout(horizontalLayout_39, 6, 0, 1, 3);

        toolButtonShowclickTimeDefault = new QToolButton(tab);
        toolButtonShowclickTimeDefault->setObjectName("toolButtonShowclickTimeDefault");
        toolButtonShowclickTimeDefault->setText(QString::fromUtf8(""));
        toolButtonShowclickTimeDefault->setIcon(icon7);

        gridLayoutShowClick->addWidget(toolButtonShowclickTimeDefault, 7, 3, 1, 1);

        line_8 = new QFrame(tab);
        line_8->setObjectName("line_8");
        line_8->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_8->setFrameShadow(QFrame::Plain);
        line_8->setFrameShape(QFrame::Shape::HLine);

        gridLayoutShowClick->addWidget(line_8, 1, 5, 1, 4);

        line_6 = new QFrame(tab);
        line_6->setObjectName("line_6");
        line_6->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_6->setFrameShadow(QFrame::Plain);
        line_6->setFrameShape(QFrame::Shape::HLine);

        gridLayoutShowClick->addWidget(line_6, 1, 0, 1, 4);


        verticalLayout_35->addLayout(gridLayoutShowClick);

        QIcon icon23;
        icon23.addFile(QString::fromUtf8(":/pictures/showClick/vokoShowClick.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetShowClick->addTab(tab, icon23, QString());
        tabWidgetShowClick->setTabText(tabWidgetShowClick->indexOf(tab), QString::fromUtf8(""));

        horizontalLayout_40->addWidget(tabWidgetShowClick);

        tabWidgetSideBar->addTab(tabSidebarShowClick, icon2, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarShowClick), QString::fromUtf8(""));
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarShowClick), QString::fromUtf8("ShowClick"));
#endif // QT_CONFIG(tooltip)
        tabSidebarSnapShot = new QWidget();
        tabSidebarSnapShot->setObjectName("tabSidebarSnapShot");
        verticalLayout_36 = new QVBoxLayout(tabSidebarSnapShot);
        verticalLayout_36->setSpacing(0);
        verticalLayout_36->setContentsMargins(11, 11, 11, 11);
        verticalLayout_36->setObjectName("verticalLayout_36");
        verticalLayout_36->setContentsMargins(0, 0, 0, 0);
        verticalLayout_38 = new QVBoxLayout();
        verticalLayout_38->setSpacing(0);
        verticalLayout_38->setObjectName("verticalLayout_38");
        tabWidgetSnapshot = new QTabWidget(tabSidebarSnapShot);
        tabWidgetSnapshot->setObjectName("tabWidgetSnapshot");
        tabWidgetSnapshot->setIconSize(QSize(48, 48));
        tabSnapshot = new QWidget();
        tabSnapshot->setObjectName("tabSnapshot");
        verticalLayout_37 = new QVBoxLayout(tabSnapshot);
        verticalLayout_37->setSpacing(6);
        verticalLayout_37->setContentsMargins(11, 11, 11, 11);
        verticalLayout_37->setObjectName("verticalLayout_37");
        gridLayout_10 = new QGridLayout();
        gridLayout_10->setSpacing(6);
        gridLayout_10->setObjectName("gridLayout_10");
        label_57 = new QLabel(tabSnapshot);
        label_57->setObjectName("label_57");

        gridLayout_10->addWidget(label_57, 3, 0, 1, 1);

        toolButtonSnapshotImagePath = new QToolButton(tabSnapshot);
        toolButtonSnapshotImagePath->setObjectName("toolButtonSnapshotImagePath");
        toolButtonSnapshotImagePath->setText(QString::fromUtf8("..."));

        gridLayout_10->addWidget(toolButtonSnapshotImagePath, 2, 2, 1, 1);

        label_60 = new QLabel(tabSnapshot);
        label_60->setObjectName("label_60");
        label_60->setFont(font1);
        label_60->setText(QString::fromUtf8("Snapshot"));

        gridLayout_10->addWidget(label_60, 0, 0, 1, 2, Qt::AlignHCenter);

        lineEditSnapshotImagePath = new QLineEdit(tabSnapshot);
        lineEditSnapshotImagePath->setObjectName("lineEditSnapshotImagePath");
        lineEditSnapshotImagePath->setReadOnly(true);

        gridLayout_10->addWidget(lineEditSnapshotImagePath, 2, 1, 1, 1);

        horizontalLayout_44 = new QHBoxLayout();
        horizontalLayout_44->setSpacing(6);
        horizontalLayout_44->setObjectName("horizontalLayout_44");
        comboBoxSnapshotImageFormats = new QComboBox(tabSnapshot);
        comboBoxSnapshotImageFormats->setObjectName("comboBoxSnapshotImageFormats");

        horizontalLayout_44->addWidget(comboBoxSnapshotImageFormats);

        horizontalSpacer_24 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_44->addItem(horizontalSpacer_24);


        gridLayout_10->addLayout(horizontalLayout_44, 3, 1, 1, 1);

        checkBoxSnapshotShowBallonInSystray = new QCheckBox(tabSnapshot);
        checkBoxSnapshotShowBallonInSystray->setObjectName("checkBoxSnapshotShowBallonInSystray");

        gridLayout_10->addWidget(checkBoxSnapshotShowBallonInSystray, 6, 0, 1, 2);

        label_56 = new QLabel(tabSnapshot);
        label_56->setObjectName("label_56");

        gridLayout_10->addWidget(label_56, 2, 0, 1, 1);

        line_2 = new QFrame(tabSnapshot);
        line_2->setObjectName("line_2");
        line_2->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_2->setFrameShadow(QFrame::Plain);
        line_2->setFrameShape(QFrame::Shape::HLine);

        gridLayout_10->addWidget(line_2, 1, 0, 1, 3);

        checkBoxSnapshotHideBeforeRecording = new QCheckBox(tabSnapshot);
        checkBoxSnapshotHideBeforeRecording->setObjectName("checkBoxSnapshotHideBeforeRecording");

        gridLayout_10->addWidget(checkBoxSnapshotHideBeforeRecording, 5, 0, 1, 2);

        horizontalLayout_59 = new QHBoxLayout();
        horizontalLayout_59->setSpacing(6);
        horizontalLayout_59->setObjectName("horizontalLayout_59");
        label_59 = new QLabel(tabSnapshot);
        label_59->setObjectName("label_59");

        horizontalLayout_59->addWidget(label_59);


        gridLayout_10->addLayout(horizontalLayout_59, 4, 0, 1, 2);


        verticalLayout_37->addLayout(gridLayout_10);

        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_37->addItem(verticalSpacer_10);

        tabWidgetSnapshot->addTab(tabSnapshot, icon3, QString());
        tabWidgetSnapshot->setTabText(tabWidgetSnapshot->indexOf(tabSnapshot), QString::fromUtf8(""));

        verticalLayout_38->addWidget(tabWidgetSnapshot);

        gridLayout_12 = new QGridLayout();
        gridLayout_12->setSpacing(6);
        gridLayout_12->setObjectName("gridLayout_12");
        pushButtonSnapshotSnapshot = new QPushButton(tabSidebarSnapShot);
        pushButtonSnapshotSnapshot->setObjectName("pushButtonSnapshotSnapshot");
        pushButtonSnapshotSnapshot->setFont(font);

        gridLayout_12->addWidget(pushButtonSnapshotSnapshot, 0, 2, 1, 1);

        horizontalSpacer_31 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_12->addItem(horizontalSpacer_31, 0, 0, 1, 1);

        pushButtonSnapshotOpenfolder = new QPushButton(tabSidebarSnapShot);
        pushButtonSnapshotOpenfolder->setObjectName("pushButtonSnapshotOpenfolder");
        pushButtonSnapshotOpenfolder->setFont(font);

        gridLayout_12->addWidget(pushButtonSnapshotOpenfolder, 0, 1, 1, 1);


        verticalLayout_38->addLayout(gridLayout_12);


        verticalLayout_36->addLayout(verticalLayout_38);

        tabWidgetSideBar->addTab(tabSidebarSnapShot, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarSnapShot), QString::fromUtf8(""));
        tabSidebarShortcut = new QWidget();
        tabSidebarShortcut->setObjectName("tabSidebarShortcut");
        verticalLayout_33 = new QVBoxLayout(tabSidebarShortcut);
        verticalLayout_33->setSpacing(0);
        verticalLayout_33->setContentsMargins(11, 11, 11, 11);
        verticalLayout_33->setObjectName("verticalLayout_33");
        verticalLayout_33->setContentsMargins(0, 0, 0, 0);
        tabWidgetShortcut = new QTabWidget(tabSidebarShortcut);
        tabWidgetShortcut->setObjectName("tabWidgetShortcut");
        tabWidgetShortcut->setIconSize(QSize(48, 48));
        tabShortcut = new QWidget();
        tabShortcut->setObjectName("tabShortcut");
        verticalLayout_34 = new QVBoxLayout(tabShortcut);
        verticalLayout_34->setSpacing(6);
        verticalLayout_34->setContentsMargins(11, 11, 11, 11);
        verticalLayout_34->setObjectName("verticalLayout_34");
        frame_screencast_shortcut = new QFrame(tabShortcut);
        frame_screencast_shortcut->setObjectName("frame_screencast_shortcut");
        frame_screencast_shortcut->setFrameShape(QFrame::NoFrame);
        verticalLayout_24 = new QVBoxLayout(frame_screencast_shortcut);
        verticalLayout_24->setSpacing(6);
        verticalLayout_24->setContentsMargins(11, 11, 11, 11);
        verticalLayout_24->setObjectName("verticalLayout_24");
        verticalLayout_24->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_51 = new QHBoxLayout();
        horizontalLayout_51->setSpacing(6);
        horizontalLayout_51->setObjectName("horizontalLayout_51");
        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_51->addItem(horizontalSpacer_22);

        label_45 = new QLabel(frame_screencast_shortcut);
        label_45->setObjectName("label_45");
        label_45->setFont(font1);

        horizontalLayout_51->addWidget(label_45);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_51->addItem(horizontalSpacer_19);


        verticalLayout_24->addLayout(horizontalLayout_51);

        horizontalLayout_52 = new QHBoxLayout();
        horizontalLayout_52->setSpacing(6);
        horizontalLayout_52->setObjectName("horizontalLayout_52");
        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_52->addItem(horizontalSpacer_25);


        verticalLayout_24->addLayout(horizontalLayout_52);

        gridLayout_11 = new QGridLayout();
        gridLayout_11->setSpacing(6);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setContentsMargins(-1, -1, -1, 0);
        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_26, 1, 7, 1, 1);

        checkBox_shortcut_start_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_start_strg->setObjectName("checkBox_shortcut_start_strg");
        checkBox_shortcut_start_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_start_strg, 1, 2, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_magnification_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_magnification_alt->setObjectName("checkBox_shortcut_magnification_alt");
        checkBox_shortcut_magnification_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_magnification_alt, 3, 4, 1, 1, Qt::AlignHCenter);

        horizontalLayout_55 = new QHBoxLayout();
        horizontalLayout_55->setSpacing(6);
        horizontalLayout_55->setObjectName("horizontalLayout_55");
        label_47 = new QLabel(frame_screencast_shortcut);
        label_47->setObjectName("label_47");

        horizontalLayout_55->addWidget(label_47, 0, Qt::AlignLeft);

        horizontalSpacer_34 = new QSpacerItem(40, 20, QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Minimum);

        horizontalLayout_55->addItem(horizontalSpacer_34);


        gridLayout_11->addLayout(horizontalLayout_55, 4, 0, 1, 1);

        horizontalLayout_53 = new QHBoxLayout();
        horizontalLayout_53->setSpacing(0);
        horizontalLayout_53->setObjectName("horizontalLayout_53");
        label_40 = new QLabel(frame_screencast_shortcut);
        label_40->setObjectName("label_40");

        horizontalLayout_53->addWidget(label_40, 0, Qt::AlignLeft);

        label_46 = new QLabel(frame_screencast_shortcut);
        label_46->setObjectName("label_46");
#if QT_CONFIG(tooltip)
        label_46->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        label_46->setText(QString::fromUtf8(" / "));

        horizontalLayout_53->addWidget(label_46, 0, Qt::AlignHCenter);

        label_41 = new QLabel(frame_screencast_shortcut);
        label_41->setObjectName("label_41");

        horizontalLayout_53->addWidget(label_41, 0, Qt::AlignRight);

        horizontalSpacer_30 = new QSpacerItem(40, 20, QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Minimum);

        horizontalLayout_53->addItem(horizontalSpacer_30);


        gridLayout_11->addLayout(horizontalLayout_53, 2, 0, 1, 1);

        label_shortcut_picture_magnification = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_magnification->setObjectName("label_shortcut_picture_magnification");
        label_shortcut_picture_magnification->setText(QString::fromUtf8("Picture"));
        label_shortcut_picture_magnification->setAlignment(Qt::AlignCenter);

        gridLayout_11->addWidget(label_shortcut_picture_magnification, 3, 1, 1, 1);

        checkBox_shortcut_start_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_start_meta->setObjectName("checkBox_shortcut_start_meta");
        checkBox_shortcut_start_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_start_meta, 1, 5, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_pause_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_pause_meta->setObjectName("checkBox_shortcut_pause_meta");
        checkBox_shortcut_pause_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_pause_meta, 2, 5, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_start_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_start_shift->setObjectName("checkBox_shortcut_start_shift");
        checkBox_shortcut_start_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_start_shift, 1, 3, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_camera_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_camera_meta->setObjectName("checkBox_shortcut_camera_meta");
        checkBox_shortcut_camera_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_camera_meta, 4, 5, 1, 1, Qt::AlignHCenter);

        label_shortcut_picture_camera = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_camera->setObjectName("label_shortcut_picture_camera");
        label_shortcut_picture_camera->setText(QString::fromUtf8("Picture"));

        gridLayout_11->addWidget(label_shortcut_picture_camera, 4, 1, 1, 1, Qt::AlignHCenter);

        label_37 = new QLabel(frame_screencast_shortcut);
        label_37->setObjectName("label_37");
        label_37->setText(QString::fromUtf8("CTRL"));

        gridLayout_11->addWidget(label_37, 0, 2, 1, 1, Qt::AlignHCenter);

        toolButton_shortcut_reset_pause = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_pause->setObjectName("toolButton_shortcut_reset_pause");
        toolButton_shortcut_reset_pause->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_pause->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_pause, 2, 8, 1, 1);

        checkBox_shortcut_camera_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_camera_alt->setObjectName("checkBox_shortcut_camera_alt");
        checkBox_shortcut_camera_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_camera_alt, 4, 4, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_pause_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_pause_alt->setObjectName("checkBox_shortcut_pause_alt");
        checkBox_shortcut_pause_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_pause_alt, 2, 4, 1, 1, Qt::AlignHCenter);

        comboBox_shortcut_camera = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_camera->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_camera->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_camera->setObjectName("comboBox_shortcut_camera");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_camera->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_camera->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_camera, 4, 6, 1, 1);

        checkBox_shortcut_halo_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_halo_meta->setObjectName("checkBox_shortcut_halo_meta");
        checkBox_shortcut_halo_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_halo_meta, 6, 5, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_showclick_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_showclick_shift->setObjectName("checkBox_shortcut_showclick_shift");
        checkBox_shortcut_showclick_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_showclick_shift, 5, 3, 1, 1, Qt::AlignHCenter);

        label_shortcut_picture_halo = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_halo->setObjectName("label_shortcut_picture_halo");
        label_shortcut_picture_halo->setText(QString::fromUtf8("Picture"));

        gridLayout_11->addWidget(label_shortcut_picture_halo, 6, 1, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_magnification_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_magnification_shift->setObjectName("checkBox_shortcut_magnification_shift");
        checkBox_shortcut_magnification_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_magnification_shift, 3, 3, 1, 1, Qt::AlignHCenter);

        label_36 = new QLabel(frame_screencast_shortcut);
        label_36->setObjectName("label_36");
        label_36->setText(QString::fromUtf8("ALT"));

        gridLayout_11->addWidget(label_36, 0, 4, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_camera_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_camera_shift->setObjectName("checkBox_shortcut_camera_shift");
        checkBox_shortcut_camera_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_camera_shift, 4, 3, 1, 1, Qt::AlignHCenter);

        toolButton_shortcut_reset_showclick = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_showclick->setObjectName("toolButton_shortcut_reset_showclick");
        toolButton_shortcut_reset_showclick->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_showclick->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_showclick, 5, 8, 1, 1);

        comboBox_shortcut_halo = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_halo->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_halo->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_halo->setObjectName("comboBox_shortcut_halo");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_halo->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_halo->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_halo, 6, 6, 1, 1);

        checkBox_shortcut_magnification_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_magnification_strg->setObjectName("checkBox_shortcut_magnification_strg");
        checkBox_shortcut_magnification_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_magnification_strg, 3, 2, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_showclick_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_showclick_strg->setObjectName("checkBox_shortcut_showclick_strg");
        checkBox_shortcut_showclick_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_showclick_strg, 5, 2, 1, 1, Qt::AlignHCenter);

        label_shortcut_picture_showclick = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_showclick->setObjectName("label_shortcut_picture_showclick");
        label_shortcut_picture_showclick->setText(QString::fromUtf8("Picture"));

        gridLayout_11->addWidget(label_shortcut_picture_showclick, 5, 1, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_camera_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_camera_strg->setObjectName("checkBox_shortcut_camera_strg");
        checkBox_shortcut_camera_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_camera_strg, 4, 2, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_start_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_start_alt->setObjectName("checkBox_shortcut_start_alt");
        checkBox_shortcut_start_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_start_alt, 1, 4, 1, 1, Qt::AlignHCenter);

        toolButton_shortcut_reset_halo = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_halo->setObjectName("toolButton_shortcut_reset_halo");
        toolButton_shortcut_reset_halo->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_halo->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_halo, 6, 8, 1, 1);

        comboBox_shortcut_magnification = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_magnification->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_magnification->setObjectName("comboBox_shortcut_magnification");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_magnification->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_magnification->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_magnification, 3, 6, 1, 1);

        checkBox_shortcut_pause_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_pause_shift->setObjectName("checkBox_shortcut_pause_shift");
        checkBox_shortcut_pause_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_pause_shift, 2, 3, 1, 1, Qt::AlignHCenter);

        label_shortcut_picture_pause = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_pause->setObjectName("label_shortcut_picture_pause");
        label_shortcut_picture_pause->setText(QString::fromUtf8("Picture"));
        label_shortcut_picture_pause->setAlignment(Qt::AlignCenter);

        gridLayout_11->addWidget(label_shortcut_picture_pause, 2, 1, 1, 1);

        checkBox_shortcut_halo_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_halo_strg->setObjectName("checkBox_shortcut_halo_strg");
        checkBox_shortcut_halo_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_halo_strg, 6, 2, 1, 1, Qt::AlignHCenter);

        label_49 = new QLabel(frame_screencast_shortcut);
        label_49->setObjectName("label_49");
        label_49->setText(QString::fromUtf8("ShowClick"));

        gridLayout_11->addWidget(label_49, 5, 0, 1, 1);

        toolButton_shortcut_reset_camera = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_camera->setObjectName("toolButton_shortcut_reset_camera");
        toolButton_shortcut_reset_camera->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_camera->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_camera, 4, 8, 1, 1);

        checkBox_shortcut_showclick_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_showclick_meta->setObjectName("checkBox_shortcut_showclick_meta");
        checkBox_shortcut_showclick_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_showclick_meta, 5, 5, 1, 1, Qt::AlignHCenter);

        label_51 = new QLabel(frame_screencast_shortcut);
        label_51->setObjectName("label_51");
        label_51->setText(QString::fromUtf8("Halo"));

        gridLayout_11->addWidget(label_51, 6, 0, 1, 1);

        toolButton_shortcut_reset_start = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_start->setObjectName("toolButton_shortcut_reset_start");
        toolButton_shortcut_reset_start->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_start->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_start, 1, 8, 1, 1);

        label_35 = new QLabel(frame_screencast_shortcut);
        label_35->setObjectName("label_35");
        label_35->setText(QString::fromUtf8("SHIFT"));

        gridLayout_11->addWidget(label_35, 0, 3, 1, 1, Qt::AlignHCenter);

        horizontalLayout_50 = new QHBoxLayout();
        horizontalLayout_50->setSpacing(0);
        horizontalLayout_50->setObjectName("horizontalLayout_50");
        label_43 = new QLabel(frame_screencast_shortcut);
        label_43->setObjectName("label_43");
        label_43->setAlignment(Qt::AlignCenter);

        horizontalLayout_50->addWidget(label_43, 0, Qt::AlignLeft);

        label_48 = new QLabel(frame_screencast_shortcut);
        label_48->setObjectName("label_48");
        label_48->setText(QString::fromUtf8("/"));
        label_48->setAlignment(Qt::AlignCenter);

        horizontalLayout_50->addWidget(label_48, 0, Qt::AlignHCenter);

        label_44 = new QLabel(frame_screencast_shortcut);
        label_44->setObjectName("label_44");
        label_44->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_50->addWidget(label_44, 0, Qt::AlignRight);

        horizontalSpacer_27 = new QSpacerItem(40, 20, QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Minimum);

        horizontalLayout_50->addItem(horizontalSpacer_27);


        gridLayout_11->addLayout(horizontalLayout_50, 1, 0, 1, 1);

        checkBox_shortcut_showclick_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_showclick_alt->setObjectName("checkBox_shortcut_showclick_alt");
        checkBox_shortcut_showclick_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_showclick_alt, 5, 4, 1, 1, Qt::AlignHCenter);

        comboBox_shortcut_pause = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_pause->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_pause->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_pause->setObjectName("comboBox_shortcut_pause");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_pause->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_pause->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_pause, 2, 6, 1, 1);

        horizontalLayout_54 = new QHBoxLayout();
        horizontalLayout_54->setSpacing(6);
        horizontalLayout_54->setObjectName("horizontalLayout_54");
        label_42 = new QLabel(frame_screencast_shortcut);
        label_42->setObjectName("label_42");

        horizontalLayout_54->addWidget(label_42, 0, Qt::AlignLeft);

        horizontalSpacer_32 = new QSpacerItem(40, 20, QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Minimum);

        horizontalLayout_54->addItem(horizontalSpacer_32);


        gridLayout_11->addLayout(horizontalLayout_54, 3, 0, 1, 1);

        checkBox_shortcut_pause_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_pause_strg->setObjectName("checkBox_shortcut_pause_strg");
        checkBox_shortcut_pause_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_pause_strg, 2, 2, 1, 1, Qt::AlignHCenter);

        toolButton_shortcut_reset_magnification = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_magnification->setObjectName("toolButton_shortcut_reset_magnification");
        toolButton_shortcut_reset_magnification->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_magnification->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_magnification, 3, 8, 1, 1);

        label_38 = new QLabel(frame_screencast_shortcut);
        label_38->setObjectName("label_38");
        label_38->setText(QString::fromUtf8("META"));

        gridLayout_11->addWidget(label_38, 0, 5, 1, 1, Qt::AlignHCenter);

        comboBox_shortcut_start = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_start->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_start->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_start->setObjectName("comboBox_shortcut_start");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_start->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_start->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_start, 1, 6, 1, 1);

        comboBox_shortcut_showclick = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_showclick->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_showclick->setObjectName("comboBox_shortcut_showclick");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_showclick->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_showclick->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_showclick, 5, 6, 1, 1);

        checkBox_shortcut_halo_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_halo_shift->setObjectName("checkBox_shortcut_halo_shift");
        checkBox_shortcut_halo_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_halo_shift, 6, 3, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_halo_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_halo_alt->setObjectName("checkBox_shortcut_halo_alt");
        checkBox_shortcut_halo_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_halo_alt, 6, 4, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_magnification_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_magnification_meta->setObjectName("checkBox_shortcut_magnification_meta");
        checkBox_shortcut_magnification_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_magnification_meta, 3, 5, 1, 1, Qt::AlignHCenter);

        label_shortcut_picture_start = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_start->setObjectName("label_shortcut_picture_start");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(label_shortcut_picture_start->sizePolicy().hasHeightForWidth());
        label_shortcut_picture_start->setSizePolicy(sizePolicy6);
        label_shortcut_picture_start->setText(QString::fromUtf8("Picture"));
        label_shortcut_picture_start->setAlignment(Qt::AlignCenter);

        gridLayout_11->addWidget(label_shortcut_picture_start, 1, 1, 1, 1);

        label_58 = new QLabel(frame_screencast_shortcut);
        label_58->setObjectName("label_58");

        gridLayout_11->addWidget(label_58, 7, 0, 1, 1);

        label_shortcut_picture_snapshot = new QLabel(frame_screencast_shortcut);
        label_shortcut_picture_snapshot->setObjectName("label_shortcut_picture_snapshot");
        label_shortcut_picture_snapshot->setText(QString::fromUtf8("Picture"));

        gridLayout_11->addWidget(label_shortcut_picture_snapshot, 7, 1, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_snapshot_strg = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_snapshot_strg->setObjectName("checkBox_shortcut_snapshot_strg");
        checkBox_shortcut_snapshot_strg->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_snapshot_strg, 7, 2, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_snapshot_shift = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_snapshot_shift->setObjectName("checkBox_shortcut_snapshot_shift");
        checkBox_shortcut_snapshot_shift->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_snapshot_shift, 7, 3, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_snapshot_alt = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_snapshot_alt->setObjectName("checkBox_shortcut_snapshot_alt");
        checkBox_shortcut_snapshot_alt->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_snapshot_alt, 7, 4, 1, 1, Qt::AlignHCenter);

        checkBox_shortcut_snapshot_meta = new QCheckBox(frame_screencast_shortcut);
        checkBox_shortcut_snapshot_meta->setObjectName("checkBox_shortcut_snapshot_meta");
        checkBox_shortcut_snapshot_meta->setText(QString::fromUtf8(""));

        gridLayout_11->addWidget(checkBox_shortcut_snapshot_meta, 7, 5, 1, 1, Qt::AlignHCenter);

        comboBox_shortcut_snapshot = new QComboBox(frame_screencast_shortcut);
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("A"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("B"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("C"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("D"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("E"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("G"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("H"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("I"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("J"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("K"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("L"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("M"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("N"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("O"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("P"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("Q"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("R"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("S"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("T"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("U"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("V"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("W"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("X"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("Y"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("Z"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F1"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F2"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F3"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F4"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F5"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F6"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F7"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F8"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F9"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F10"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F11"));
        comboBox_shortcut_snapshot->addItem(QString::fromUtf8("F12"));
        comboBox_shortcut_snapshot->setObjectName("comboBox_shortcut_snapshot");
#if QT_CONFIG(tooltip)
        comboBox_shortcut_snapshot->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        comboBox_shortcut_snapshot->setCurrentText(QString::fromUtf8("A"));

        gridLayout_11->addWidget(comboBox_shortcut_snapshot, 7, 6, 1, 1);

        toolButton_shortcut_reset_snapshot = new QToolButton(frame_screencast_shortcut);
        toolButton_shortcut_reset_snapshot->setObjectName("toolButton_shortcut_reset_snapshot");
        toolButton_shortcut_reset_snapshot->setText(QString::fromUtf8(""));
        toolButton_shortcut_reset_snapshot->setIcon(icon7);

        gridLayout_11->addWidget(toolButton_shortcut_reset_snapshot, 7, 8, 1, 1);


        verticalLayout_24->addLayout(gridLayout_11);

        verticalSpacer_24 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_24->addItem(verticalSpacer_24);

        horizontalLayout_56 = new QHBoxLayout();
        horizontalLayout_56->setSpacing(6);
        horizontalLayout_56->setObjectName("horizontalLayout_56");
        label_39 = new QLabel(frame_screencast_shortcut);
        label_39->setObjectName("label_39");
        label_39->setMaximumSize(QSize(16, 16));
        label_39->setText(QString::fromUtf8(""));
        label_39->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/accept.png")));
        label_39->setScaledContents(true);

        horizontalLayout_56->addWidget(label_39);

        label_50 = new QLabel(frame_screencast_shortcut);
        label_50->setObjectName("label_50");
        label_50->setWordWrap(true);
        label_50->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_56->addWidget(label_50);


        verticalLayout_24->addLayout(horizontalLayout_56);

        horizontalLayout_57 = new QHBoxLayout();
        horizontalLayout_57->setSpacing(6);
        horizontalLayout_57->setObjectName("horizontalLayout_57");
        label_52 = new QLabel(frame_screencast_shortcut);
        label_52->setObjectName("label_52");
        label_52->setMaximumSize(QSize(16, 16));
        label_52->setText(QString::fromUtf8(""));
        label_52->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/missing.png")));
        label_52->setScaledContents(true);

        horizontalLayout_57->addWidget(label_52);

        label_53 = new QLabel(frame_screencast_shortcut);
        label_53->setObjectName("label_53");
        label_53->setWordWrap(true);
        label_53->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_57->addWidget(label_53);


        verticalLayout_24->addLayout(horizontalLayout_57);

        verticalSpacer_15 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_24->addItem(verticalSpacer_15);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_54 = new QLabel(frame_screencast_shortcut);
        label_54->setObjectName("label_54");
        label_54->setFont(font);
        label_54->setWordWrap(true);
        label_54->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_4->addWidget(label_54);


        verticalLayout_24->addLayout(horizontalLayout_4);

        verticalSpacer_22 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_24->addItem(verticalSpacer_22);


        verticalLayout_34->addWidget(frame_screencast_shortcut);

        tabWidgetShortcut->addTab(tabShortcut, icon4, QString());
        tabWidgetShortcut->setTabText(tabWidgetShortcut->indexOf(tabShortcut), QString::fromUtf8(""));

        verticalLayout_33->addWidget(tabWidgetShortcut);

        tabWidgetSideBar->addTab(tabSidebarShortcut, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarShortcut), QString::fromUtf8(""));
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarShortcut), QString::fromUtf8("Shortcut"));
#endif // QT_CONFIG(tooltip)
        tabSidebarPlayer = new QWidget();
        tabSidebarPlayer->setObjectName("tabSidebarPlayer");
        verticalLayoutTabSidebarPlayer = new QVBoxLayout(tabSidebarPlayer);
        verticalLayoutTabSidebarPlayer->setSpacing(0);
        verticalLayoutTabSidebarPlayer->setContentsMargins(11, 11, 11, 11);
        verticalLayoutTabSidebarPlayer->setObjectName("verticalLayoutTabSidebarPlayer");
        verticalLayoutTabSidebarPlayer->setContentsMargins(0, 0, 0, 1);
        tabWidgetPlayer = new QTabWidget(tabSidebarPlayer);
        tabWidgetPlayer->setObjectName("tabWidgetPlayer");
        tabWidgetPlayer->setIconSize(QSize(48, 48));
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        tabWidgetPlayer->addTab(tab_2, icon5, QString());
        tabWidgetPlayer->setTabText(tabWidgetPlayer->indexOf(tab_2), QString::fromUtf8(""));

        verticalLayoutTabSidebarPlayer->addWidget(tabWidgetPlayer);

        horizontalLayout_68 = new QHBoxLayout();
        horizontalLayout_68->setSpacing(6);
        horizontalLayout_68->setObjectName("horizontalLayout_68");
        horizontalSpacer_50 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_68->addItem(horizontalSpacer_50);

        pushButtonPlayer = new QPushButton(tabSidebarPlayer);
        pushButtonPlayer->setObjectName("pushButtonPlayer");
        pushButtonPlayer->setFont(font);

        horizontalLayout_68->addWidget(pushButtonPlayer);

        horizontalSpacer_54 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_68->addItem(horizontalSpacer_54);


        verticalLayoutTabSidebarPlayer->addLayout(horizontalLayout_68);

        QIcon icon24;
        icon24.addFile(QString::fromUtf8(":/pictures/player/player-sidebar.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetSideBar->addTab(tabSidebarPlayer, icon24, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarPlayer), QString::fromUtf8(""));
        tabSidebarLog = new QWidget();
        tabSidebarLog->setObjectName("tabSidebarLog");
        verticalLayout_25 = new QVBoxLayout(tabSidebarLog);
        verticalLayout_25->setSpacing(0);
        verticalLayout_25->setContentsMargins(11, 11, 11, 11);
        verticalLayout_25->setObjectName("verticalLayout_25");
        verticalLayout_25->setContentsMargins(0, 0, 0, 0);
        tabWidgetLog = new QTabWidget(tabSidebarLog);
        tabWidgetLog->setObjectName("tabWidgetLog");
        tabWidgetLog->setIconSize(QSize(48, 48));
        tabLog = new QWidget();
        tabLog->setObjectName("tabLog");
        verticalLayout_26 = new QVBoxLayout(tabLog);
        verticalLayout_26->setSpacing(6);
        verticalLayout_26->setContentsMargins(11, 11, 11, 11);
        verticalLayout_26->setObjectName("verticalLayout_26");
        verticalLayout_26->setContentsMargins(-1, -1, -1, 6);
        textBrowser = new QTextBrowser(tabLog);
        textBrowser->setObjectName("textBrowser");

        verticalLayout_26->addWidget(textBrowser);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(6);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_16);

        pushButton_log_openfolder = new QPushButton(tabLog);
        pushButton_log_openfolder->setObjectName("pushButton_log_openfolder");
        pushButton_log_openfolder->setFont(font);

        horizontalLayout_8->addWidget(pushButton_log_openfolder);

        pushButton_log_refresh = new QPushButton(tabLog);
        pushButton_log_refresh->setObjectName("pushButton_log_refresh");
        pushButton_log_refresh->setFont(font);
        pushButton_log_refresh->setText(QString::fromUtf8("Refresh"));

        horizontalLayout_8->addWidget(pushButton_log_refresh);


        verticalLayout_26->addLayout(horizontalLayout_8);

        tabWidgetLog->addTab(tabLog, icon6, QString());
        tabWidgetLog->setTabText(tabWidgetLog->indexOf(tabLog), QString::fromUtf8(""));

        verticalLayout_25->addWidget(tabWidgetLog);

        QIcon icon25;
        icon25.addFile(QString::fromUtf8(":/pictures/log/log-sidebar.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetSideBar->addTab(tabSidebarLog, icon25, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarLog), QString::fromUtf8(""));

        horizontalLayout_49->addWidget(tabWidgetSideBar);

        formMainWindow->setCentralWidget(centralWidget);
        QWidget::setTabOrder(tabWidgetScreencast, radioButtonScreencastFullscreen);
        QWidget::setTabOrder(radioButtonScreencastFullscreen, comboBoxScreencastScreen);
        QWidget::setTabOrder(comboBoxScreencastScreen, help_screencast_fullscreen);
        QWidget::setTabOrder(help_screencast_fullscreen, radioButtonScreencastWindow);
        QWidget::setTabOrder(radioButtonScreencastWindow, help_screencast_window);
        QWidget::setTabOrder(help_screencast_window, radioButtonScreencastArea);
        QWidget::setTabOrder(radioButtonScreencastArea, help_screencast_area);
        QWidget::setTabOrder(help_screencast_area, pushButtonStart);
        QWidget::setTabOrder(pushButtonStart, pushButtonStop);
        QWidget::setTabOrder(pushButtonStop, pushButtonPause);
        QWidget::setTabOrder(pushButtonPause, pushButtonContinue);
        QWidget::setTabOrder(pushButtonContinue, pushButtonPlay);
        QWidget::setTabOrder(pushButtonPlay, pushButtonScreencastOpenfolder);
        QWidget::setTabOrder(pushButtonScreencastOpenfolder, help_screencast_execute);
        QWidget::setTabOrder(help_screencast_execute, help_screencast_videocodec);
        QWidget::setTabOrder(help_screencast_videocodec, checkBoxStartTime);
        QWidget::setTabOrder(checkBoxStartTime, help_screencast_starttimer);
        QWidget::setTabOrder(help_screencast_starttimer, checkBoxStopRecordingAfter);
        QWidget::setTabOrder(checkBoxStopRecordingAfter, help_screencast_stoptimer);
        QWidget::setTabOrder(help_screencast_stoptimer, lineEditVideoPath);
        QWidget::setTabOrder(lineEditVideoPath, checkBoxMinimizedWhenRecordingStarts);
        QWidget::setTabOrder(checkBoxMinimizedWhenRecordingStarts, checkBoxStartsMinimized);
        QWidget::setTabOrder(checkBoxStartsMinimized, scrollAreaAvailable);
        QWidget::setTabOrder(scrollAreaAvailable, help_screencast_avalaible);
        QWidget::setTabOrder(help_screencast_avalaible, tabWidgetCamera);
        QWidget::setTabOrder(tabWidgetCamera, tabWidgetLog);

        retranslateUi(formMainWindow);

        tabWidgetSideBar->setCurrentIndex(0);
        tabWidgetScreencast->setCurrentIndex(2);
        comboBoxx264Preset->setCurrentIndex(1);
        tabWidgetCamera->setCurrentIndex(0);
        tabWidgetShowClick->setCurrentIndex(0);
        tabWidgetSnapshot->setCurrentIndex(0);
        tabWidgetShortcut->setCurrentIndex(0);
        comboBox_shortcut_camera->setCurrentIndex(0);
        comboBox_shortcut_halo->setCurrentIndex(0);
        comboBox_shortcut_magnification->setCurrentIndex(0);
        comboBox_shortcut_pause->setCurrentIndex(0);
        comboBox_shortcut_start->setCurrentIndex(0);
        comboBox_shortcut_showclick->setCurrentIndex(0);
        comboBox_shortcut_snapshot->setCurrentIndex(0);
        tabWidgetPlayer->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(formMainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *formMainWindow)
    {
#if QT_CONFIG(tooltip)
        toolButtonScreencastAreaReset->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_window->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonScreencastFullscreen->setText(QCoreApplication::translate("formMainWindow", "Fullscreen", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_fullscreen->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonScreencastWindow->setText(QCoreApplication::translate("formMainWindow", "Window", nullptr));
        radioButtonScreencastArea->setText(QCoreApplication::translate("formMainWindow", "Area", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_area->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_audio->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelAudioCodec->setText(QCoreApplication::translate("formMainWindow", "Audiocodec", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_audiocodec->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMagnifier->setText(QCoreApplication::translate("formMainWindow", "Magnification", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_magnifier->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelScreencastCountdownText->setText(QCoreApplication::translate("formMainWindow", "Countdown", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_countdown->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        label_25->setText(QCoreApplication::translate("formMainWindow", "Audiocodec", nullptr));
        label_14->setText(QCoreApplication::translate("formMainWindow", "Record Time:", nullptr));
        label_12->setText(QCoreApplication::translate("formMainWindow", "Free disk space:", nullptr));
        label_23->setText(QCoreApplication::translate("formMainWindow", "Format", nullptr));
        label_24->setText(QCoreApplication::translate("formMainWindow", "Videocodec", nullptr));
        label_29->setText(QCoreApplication::translate("formMainWindow", "Frames", nullptr));
        label_13->setText(QCoreApplication::translate("formMainWindow", "Video size:", nullptr));
        label_17->setText(QCoreApplication::translate("formMainWindow", "Information", nullptr));


#if QT_CONFIG(tooltip)
        toolButtonx264Reset->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonOpenh264Reset->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFormat->setText(QCoreApplication::translate("formMainWindow", "Format", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonFramesReset->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_frames->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMouseCursorOnOff->setText(QCoreApplication::translate("formMainWindow", "Do not record mouse cursor", nullptr));
        labelVideoCodec->setText(QCoreApplication::translate("formMainWindow", "Videocodec", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_nomousecursor->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFrames->setText(QCoreApplication::translate("formMainWindow", "Frames", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_videocodec->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_format->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_limitoffreediskspace->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_SecondWaitBeforeRecording->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        LabelVideoPath->setText(QCoreApplication::translate("formMainWindow", "Videopath", nullptr));
        comboBoxOnlineHelp->setItemText(0, QCoreApplication::translate("formMainWindow", "Automatically", nullptr));

#if QT_CONFIG(tooltip)
        help_screencast_startsminimized->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxShowInSystray->setText(QCoreApplication::translate("formMainWindow", "Show in systray", nullptr));
        checkBoxShowInSystrayAlternative->setText(QCoreApplication::translate("formMainWindow", "Show in systray", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_deleteallsettings->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxStartsMinimized->setText(QCoreApplication::translate("formMainWindow", "Starts minimized", nullptr));
        label_10->setText(QCoreApplication::translate("formMainWindow", "Limit of free disk space", nullptr));
        label_11->setText(QCoreApplication::translate("formMainWindow", "Megabyte", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_lookforupdates->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        help_screencast_lookforupdates->setText(QCoreApplication::translate("formMainWindow", "Help", nullptr));
        checkBoxMinimizedWhenRecordingStarts->setText(QCoreApplication::translate("formMainWindow", "Minimized when recording starts", nullptr));
        checkBoxLookForUpdates->setText(QCoreApplication::translate("formMainWindow", "Look for updates", nullptr));
        label_18->setText(QCoreApplication::translate("formMainWindow", "Second wait before recording", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_showinsystray->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxResetAtNextStart->setText(QCoreApplication::translate("formMainWindow", "Reset all settings at the next start", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_videopath->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonShowInSystrayAlternativeReset->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_minimizedwhenrecordingstarts->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonGstreamerDebugLevel->setToolTip(QCoreApplication::translate("formMainWindow", "Open folder", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonGstreamerDebugLevel->setText(QCoreApplication::translate("formMainWindow", "Folder", nullptr));
        help_screencast_gstreamerDebugLevel->setText(QCoreApplication::translate("formMainWindow", "Help", nullptr));
        labelHour->setText(QCoreApplication::translate("formMainWindow", "Hour", nullptr));
        labelMinute->setText(QCoreApplication::translate("formMainWindow", "Minute", nullptr));
        checkBoxStartTime->setText(QCoreApplication::translate("formMainWindow", "Start the timer", nullptr));
        checkBoxStopRecordingAfter->setText(QCoreApplication::translate("formMainWindow", "Stop recording after", nullptr));
        label_7->setText(QCoreApplication::translate("formMainWindow", "Hours", nullptr));
        label_8->setText(QCoreApplication::translate("formMainWindow", "Minutes", nullptr));
        label_9->setText(QCoreApplication::translate("formMainWindow", "Seconds", nullptr));
        label_4->setText(QCoreApplication::translate("formMainWindow", "Format", nullptr));
        label_2->setText(QCoreApplication::translate("formMainWindow", "Video", nullptr));
        label->setText(QCoreApplication::translate("formMainWindow", "Audio", nullptr));
        label_3->setText(QCoreApplication::translate("formMainWindow", "Available", nullptr));
        label_6->setText(QCoreApplication::translate("formMainWindow", "Not available", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_avalaible->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonLicense->setText(QCoreApplication::translate("formMainWindow", "Copyright and license from pictures", nullptr));
        pushButtonImages->setText(QCoreApplication::translate("formMainWindow", "Create images of tabs ", nullptr));
        pushButtonCiscoLicense->setText(QCoreApplication::translate("formMainWindow", "License information", nullptr));
        radioButton_cisco_on->setText(QCoreApplication::translate("formMainWindow", "ON", nullptr));
        radioButton_cisco_off->setText(QCoreApplication::translate("formMainWindow", "OFF", nullptr));
        pushButtonStart->setText(QCoreApplication::translate("formMainWindow", "Start", nullptr));
        pushButtonStop->setText(QCoreApplication::translate("formMainWindow", "Stop", nullptr));
        pushButtonPause->setText(QCoreApplication::translate("formMainWindow", "Pause", nullptr));
        pushButtonContinue->setText(QCoreApplication::translate("formMainWindow", "Continue", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonPlay->setToolTip(QCoreApplication::translate("formMainWindow", "Play last record", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonPlay->setText(QCoreApplication::translate("formMainWindow", "Play", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonScreencastOpenfolder->setToolTip(QCoreApplication::translate("formMainWindow", "Open folder", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonScreencastOpenfolder->setText(QCoreApplication::translate("formMainWindow", "Folder", nullptr));
        pushButtonScreencastSnapshot->setText(QCoreApplication::translate("formMainWindow", "Snapshot", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_execute->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarScreencast), QCoreApplication::translate("formMainWindow", "Screencast", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_camera_camera->setToolTip(QCoreApplication::translate("formMainWindow", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCameraInvert->setText(QCoreApplication::translate("formMainWindow", "Invert", nullptr));
        checkBoxCameraGray->setText(QCoreApplication::translate("formMainWindow", "Gray", nullptr));
        checkBoxCameraMono->setText(QCoreApplication::translate("formMainWindow", "Black-and-white", nullptr));
        checkBoxCameraOnOff->setText(QCoreApplication::translate("formMainWindow", "Camera", nullptr));
        checkBoxCameraMirrorVertical->setText(QCoreApplication::translate("formMainWindow", "Flip vertical", nullptr));
        checkBoxCameraMirrorHorizontal->setText(QCoreApplication::translate("formMainWindow", "Flip horizontal", nullptr));
        checkBoxCameraWindowFrame->setText(QCoreApplication::translate("formMainWindow", "Remove window frame", nullptr));
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarCamera), QCoreApplication::translate("formMainWindow", "Camera", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonHaloOpacityDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonHaloDiameterDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonShowclickColorDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonShowclickDiameterDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonShowclickOpacityDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonHaloColorDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonHaloHoleDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonShowclickTimeDefault->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        label_57->setText(QCoreApplication::translate("formMainWindow", "Format", nullptr));
        checkBoxSnapshotShowBallonInSystray->setText(QCoreApplication::translate("formMainWindow", "Show in systray", nullptr));
        label_56->setText(QCoreApplication::translate("formMainWindow", "Imagepath", nullptr));
        checkBoxSnapshotHideBeforeRecording->setText(QCoreApplication::translate("formMainWindow", "Hide this window", nullptr));
        label_59->setText(QCoreApplication::translate("formMainWindow", "Seconds wait before recording", nullptr));
        pushButtonSnapshotSnapshot->setText(QCoreApplication::translate("formMainWindow", "Snapshot", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonSnapshotOpenfolder->setToolTip(QCoreApplication::translate("formMainWindow", "Open folder", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonSnapshotOpenfolder->setText(QCoreApplication::translate("formMainWindow", "Folder", nullptr));
        label_45->setText(QCoreApplication::translate("formMainWindow", "Global keyboard shortcuts", nullptr));
        label_47->setText(QCoreApplication::translate("formMainWindow", "Camera", nullptr));
        label_40->setText(QCoreApplication::translate("formMainWindow", "Pause", nullptr));
        label_41->setText(QCoreApplication::translate("formMainWindow", "Continue", nullptr));
#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_pause->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)

#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_showclick->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)

#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_halo->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)

#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_camera->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_start->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        label_43->setText(QCoreApplication::translate("formMainWindow", "Start", nullptr));
        label_44->setText(QCoreApplication::translate("formMainWindow", "Stop", nullptr));

        label_42->setText(QCoreApplication::translate("formMainWindow", "Magnification", nullptr));
#if QT_CONFIG(tooltip)
        toolButton_shortcut_reset_magnification->setToolTip(QCoreApplication::translate("formMainWindow", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)


        label_58->setText(QCoreApplication::translate("formMainWindow", "Snapshot", nullptr));

        label_50->setText(QCoreApplication::translate("formMainWindow", "Assigned shortcut keys.", nullptr));
        label_53->setText(QCoreApplication::translate("formMainWindow", "Keyboard shortcut not assigned or assigned more than once.", nullptr));
        label_54->setText(QCoreApplication::translate("formMainWindow", "If it shows assigned but does not work, it is being used by another program.", nullptr));
        pushButtonPlayer->setText(QCoreApplication::translate("formMainWindow", "Player", nullptr));
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarPlayer), QCoreApplication::translate("formMainWindow", "Player", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_log_openfolder->setText(QCoreApplication::translate("formMainWindow", "Folder", nullptr));
#if QT_CONFIG(tooltip)
        tabWidgetSideBar->setTabToolTip(tabWidgetSideBar->indexOf(tabSidebarLog), QCoreApplication::translate("formMainWindow", "Log", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)formMainWindow;
    } // retranslateUi

};

namespace Ui {
    class formMainWindow: public Ui_formMainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FORMMAINWINDOW_H
